@@ -25,11 +25,9 @@ import static java.util.stream.Stream.concat;
 import com.google.common.annotations.GwtIncompatible;
 import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.base.Converter;
-import com.google.common.base.Objects;
 import com.google.common.collect.ClassToInstanceMap;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableSet;
-import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 import com.google.common.collect.MutableClassToInstanceMap;
 import com.google.common.reflect.Invokable;
@@ -46,8 +44,10 @@ import java.lang.reflect.Method;
 import java.lang.reflect.Modifier;
 import java.lang.reflect.ParameterizedType;
 import java.lang.reflect.Type;
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
+import java.util.Objects;
 import java.util.concurrent.ConcurrentMap;
 import junit.framework.Assert;
 import org.jspecify.annotations.NullMarked;
@@ -76,7 +76,7 @@ import org.jspecify.annotations.Nullable;
 public final class NullPointerTester {
 
   private final ClassToInstanceMap<Object> defaults = MutableClassToInstanceMap.create();
-  private final List<Member> ignoredMembers = Lists.newArrayList();
+  private final List<Member> ignoredMembers = new ArrayList<>();
 
   private ExceptionTypePolicy policy = ExceptionTypePolicy.NPE_OR_UOE;
 
@@ -365,7 +365,7 @@ public final class NullPointerTester {
 
     @Override
     public int hashCode() {
-      return Objects.hashCode(name, parameterTypes);
+      return Objects.hash(name, parameterTypes);
     }
   }
 
@@ -549,7 +549,29 @@ public final class NullPointerTester {
   }
 
   private boolean isIgnored(Member member) {
-    return member.isSynthetic() || ignoredMembers.contains(member) || isEquals(member);
+    return member.isSynthetic()
+        || ignoredMembers.contains(member)
+        || isEquals(member)
+        /*
+         * We can assume that Kotlin code is performing the null checks that we want, since kotlinc
+         * inserts checks automatically for non-private functions (which are the only kind that we
+         * check).
+         *
+         * We *would* just check such functions redundantly, but kotlinc emits its nullness
+         * annotations in the form of JetBrains annotations, which have only class retention and
+         * thus are invisible at runtime. Thus, we conclude that the parameter types are
+         * *non*-nullable, even when they are declared as `Foo?`.
+         */
+        || hasAutomaticNullChecksFromKotlin(member);
+  }
+
+  private static boolean hasAutomaticNullChecksFromKotlin(Member member) {
+    for (Annotation annotation : member.getDeclaringClass().getAnnotations()) {
+      if (annotation.annotationType().getName().equals("kotlin.Metadata")) {
+        return true;
+      }
+    }
+    return false;
   }
 
   /**
@@ -609,7 +631,7 @@ public final class NullPointerTester {
       }
     };
 
-    public abstract boolean isExpectedType(Throwable cause);
+    abstract boolean isExpectedType(Throwable cause);
   }
 
   private static boolean annotatedTypeExists() {
@@ -638,7 +660,6 @@ public final class NullPointerTester {
    * don't know that anyone uses it there, anyway.
    */
   private enum NullnessAnnotationReader {
-    @SuppressWarnings("Java7ApiChecker")
     FROM_DECLARATION_AND_TYPE_USE_ANNOTATIONS {
       @Override
       boolean isNullable(Invokable<?, ?> invokable) {
