@@ -16,7 +16,6 @@
 
 package com.google.common.collect.testing;
 
-import static com.google.common.collect.Lists.newArrayList;
 import static com.google.common.collect.testing.testers.CollectionAddAllTester.getAddAllUnsupportedNonePresentMethod;
 import static com.google.common.collect.testing.testers.CollectionAddAllTester.getAddAllUnsupportedSomePresentMethod;
 import static com.google.common.collect.testing.testers.CollectionAddTester.getAddUnsupportedNotPresentMethod;
@@ -29,6 +28,7 @@ import static com.google.common.collect.testing.testers.MapPutTester.getPutNullK
 import static java.util.Arrays.asList;
 
 import java.lang.reflect.Method;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 import java.util.Map;
@@ -79,7 +79,7 @@ public class OpenJdk6MapTests extends TestsForMapsInJavaUtil {
 
   @Override
   protected Collection<Method> suppressForConcurrentSkipListMap() {
-    List<Method> methods = newArrayList();
+    List<Method> methods = new ArrayList<>();
     methods.addAll(super.suppressForConcurrentSkipListMap());
     methods.add(getContainsEntryWithIncomparableKeyMethod());
     methods.add(getContainsEntryWithIncomparableValueMethod());
