@@ -26,13 +26,9 @@ import com.google.caliper.Param;
 import com.google.caliper.api.Footprint;
 import com.google.caliper.api.VmOptions;
 import com.google.common.base.Preconditions;
-import com.google.common.collect.Lists;
 import com.google.common.util.concurrent.AbstractFutureBenchmarks.OldAbstractFuture;
 import com.google.errorprone.annotations.concurrent.GuardedBy;
-import java.lang.reflect.Field;
-import java.security.AccessController;
-import java.security.PrivilegedActionException;
-import java.security.PrivilegedExceptionAction;
+import java.util.LinkedList;
 import java.util.Queue;
 import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.CountDownLatch;
@@ -42,11 +38,12 @@ import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.logging.Level;
 import java.util.logging.Logger;
-import org.checkerframework.checker.nullness.qual.Nullable;
-import sun.misc.Unsafe;
+import org.jspecify.annotations.NullUnmarked;
+import org.jspecify.annotations.Nullable;
 
 /** Benchmarks for {@link ExecutionList}. */
 @VmOptions({"-Xms8g", "-Xmx8g"})
+@NullUnmarked
 public class ExecutionListBenchmark {
   private static final int NUM_THREADS = 10; // make a param?
 
@@ -55,6 +52,7 @@ public class ExecutionListBenchmark {
     void add(Runnable runnable, Executor executor);
 
     void execute();
+
     /** Returns the underlying implementation, useful for the Footprint benchmark. */
     Object getImpl();
   }
@@ -83,29 +81,6 @@ public class ExecutionListBenchmark {
         };
       }
     },
-    NEW_WITH_CAS {
-      @Override
-      ExecutionListWrapper newExecutionList() {
-        return new ExecutionListWrapper() {
-          final ExecutionListCAS list = new ExecutionListCAS();
-
-          @Override
-          public void add(Runnable runnable, Executor executor) {
-            list.add(runnable, executor);
-          }
-
-          @Override
-          public void execute() {
-            list.execute();
-          }
-
-          @Override
-          public Object getImpl() {
-            return list;
-          }
-        };
-      }
-    },
     NEW_WITH_QUEUE {
       @Override
       ExecutionListWrapper newExecutionList() {
@@ -254,7 +229,7 @@ public class ExecutionListBenchmark {
             SECONDS,
             new ArrayBlockingQueue<Runnable>(1000));
     executorService.prestartAllCoreThreads();
-    final AtomicInteger integer = new AtomicInteger();
+    AtomicInteger integer = new AtomicInteger();
     // Execute a bunch of tasks to ensure that our threads are allocated and hot
     for (int i = 0; i < NUM_THREADS * 10; i++) {
       @SuppressWarnings("unused") // https://errorprone.info/bugpattern/FutureReturnValueIgnored
@@ -324,7 +299,7 @@ public class ExecutionListBenchmark {
       };
 
   @Benchmark
-  int addThenExecute_multiThreaded(final int reps) throws InterruptedException {
+  int addThenExecute_multiThreaded(int reps) throws InterruptedException {
     Runnable addTask =
         new Runnable() {
           @Override
@@ -351,7 +326,7 @@ public class ExecutionListBenchmark {
   }
 
   @Benchmark
-  int executeThenAdd_multiThreaded(final int reps) throws InterruptedException {
+  int executeThenAdd_multiThreaded(int reps) throws InterruptedException {
     Runnable addTask =
         new Runnable() {
           @Override
@@ -380,10 +355,10 @@ public class ExecutionListBenchmark {
   // This is the old implementation of ExecutionList using a LinkedList.
   private static final class OldExecutionList {
     static final Logger log = Logger.getLogger(OldExecutionList.class.getName());
-    final Queue<OldExecutionList.RunnableExecutorPair> runnables = Lists.newLinkedList();
+    final Queue<OldExecutionList.RunnableExecutorPair> runnables = new LinkedList<>();
     boolean executed = false;
 
-    public void add(Runnable runnable, Executor executor) {
+    void add(Runnable runnable, Executor executor) {
       Preconditions.checkNotNull(runnable, "Runnable was null.");
       Preconditions.checkNotNull(executor, "Executor was null.");
 
@@ -402,7 +377,7 @@ public class ExecutionListBenchmark {
       }
     }
 
-    public void execute() {
+    void execute() {
       synchronized (runnables) {
         if (executed) {
           return;
@@ -450,7 +425,7 @@ public class ExecutionListBenchmark {
     @GuardedBy("this")
     private boolean executed;
 
-    public void add(Runnable runnable, Executor executor) {
+    void add(Runnable runnable, Executor executor) {
       Preconditions.checkNotNull(runnable, "Runnable was null.");
       Preconditions.checkNotNull(executor, "Executor was null.");
 
@@ -463,7 +438,7 @@ public class ExecutionListBenchmark {
       executeListener(runnable, executor);
     }
 
-    public void execute() {
+    void execute() {
       RunnableExecutorPair list;
       synchronized (this) {
         if (executed) {
@@ -493,7 +468,7 @@ public class ExecutionListBenchmark {
     private static final class RunnableExecutorPair {
       final Runnable runnable;
       final Executor executor;
-      @Nullable RunnableExecutorPair next;
+      @Nullable final RunnableExecutorPair next;
 
       RunnableExecutorPair(Runnable runnable, Executor executor, RunnableExecutorPair next) {
         this.runnable = runnable;
@@ -517,7 +492,7 @@ public class ExecutionListBenchmark {
     @GuardedBy("this")
     private boolean executed;
 
-    public void add(Runnable runnable, Executor executor) {
+    void add(Runnable runnable, Executor executor) {
       Preconditions.checkNotNull(runnable, "Runnable was null.");
       Preconditions.checkNotNull(executor, "Executor was null.");
 
@@ -537,7 +512,7 @@ public class ExecutionListBenchmark {
       executeListener(runnable, executor);
     }
 
-    public void execute() {
+    void execute() {
       RunnableExecutorPair list;
       synchronized (this) {
         if (executed) {
@@ -566,8 +541,8 @@ public class ExecutionListBenchmark {
     }
 
     private static final class RunnableExecutorPair {
-      Runnable runnable;
-      Executor executor;
+      final Runnable runnable;
+      final Executor executor;
       @Nullable RunnableExecutorPair next;
 
       RunnableExecutorPair(Runnable runnable, Executor executor) {
@@ -576,125 +551,4 @@ public class ExecutionListBenchmark {
       }
     }
   }
-
-  // A version of the list that uses compare and swap to manage the stack without locks.
-  @SuppressWarnings({"SunApi", "removal"}) // b/345822163
-  private static final class ExecutionListCAS {
-    static final Logger log = Logger.getLogger(ExecutionListCAS.class.getName());
-
-    private static final Unsafe UNSAFE;
-    private static final long HEAD_OFFSET;
-
-    /**
-     * A special instance of {@link RunnableExecutorPair} that is used as a sentinel value for the
-     * bottom of the stack.
-     */
-    private static final RunnableExecutorPair NULL_PAIR = new RunnableExecutorPair(null, null);
-
-    static {
-      try {
-        UNSAFE = getUnsafe();
-        HEAD_OFFSET = UNSAFE.objectFieldOffset(ExecutionListCAS.class.getDeclaredField("head"));
-      } catch (Exception ex) {
-        throw new Error(ex);
-      }
-    }
-
-    /** TODO(lukes): This was copied verbatim from Striped64.java... standardize this? */
-    private static Unsafe getUnsafe() {
-      try {
-        return Unsafe.getUnsafe();
-      } catch (SecurityException tryReflectionInstead) {
-      }
-      try {
-        return AccessController.doPrivileged(
-            new PrivilegedExceptionAction<Unsafe>() {
-              @Override
-              public Unsafe run() throws Exception {
-                Class<Unsafe> k = Unsafe.class;
-                for (Field f : k.getDeclaredFields()) {
-                  f.setAccessible(true);
-                  Object x = f.get(null);
-                  if (k.isInstance(x)) return k.cast(x);
-                }
-                throw new NoSuchFieldError("the Unsafe");
-              }
-            });
-      } catch (PrivilegedActionException e) {
-        throw new RuntimeException("Could not initialize intrinsics", e.getCause());
-      }
-    }
-
-    private volatile RunnableExecutorPair head = NULL_PAIR;
-
-    public void add(Runnable runnable, Executor executor) {
-      Preconditions.checkNotNull(runnable, "Runnable was null.");
-      Preconditions.checkNotNull(executor, "Executor was null.");
-
-      RunnableExecutorPair newHead = new RunnableExecutorPair(runnable, executor);
-      RunnableExecutorPair oldHead;
-      do {
-        oldHead = head;
-        if (oldHead == null) {
-          // If runnables == null then execute() has been called so we should just execute our
-          // listener immediately.
-          newHead.execute();
-          return;
-        }
-        // Try to make newHead the new head of the stack at runnables.
-        newHead.next = oldHead;
-      } while (!UNSAFE.compareAndSwapObject(this, HEAD_OFFSET, oldHead, newHead));
-    }
-
-    public void execute() {
-      RunnableExecutorPair stack;
-      do {
-        stack = head;
-        if (stack == null) {
-          // If head == null then execute() has been called so we should just return
-          return;
-        }
-        // try to swap null into head.
-      } while (!UNSAFE.compareAndSwapObject(this, HEAD_OFFSET, stack, null));
-
-      RunnableExecutorPair reversedStack = null;
-      while (stack != NULL_PAIR) {
-        RunnableExecutorPair head = stack;
-        stack = stack.next;
-        head.next = reversedStack;
-        reversedStack = head;
-      }
-      stack = reversedStack;
-      while (stack != null) {
-        stack.execute();
-        stack = stack.next;
-      }
-    }
-
-    private static class RunnableExecutorPair {
-      final Runnable runnable;
-      final Executor executor;
-      // Volatile because this is written on one thread and read on another with no synchronization.
-      @Nullable volatile RunnableExecutorPair next;
-
-      RunnableExecutorPair(@Nullable Runnable runnable, @Nullable Executor executor) {
-        this.runnable = runnable;
-        this.executor = executor;
-      }
-
-      void execute() {
-        try {
-          executor.execute(runnable);
-        } catch (RuntimeException e) {
-          log.log(
-              Level.SEVERE,
-              "RuntimeException while executing runnable "
-                  + runnable
-                  + " with executor "
-                  + executor,
-              e);
-        }
-      }
-    }
-  }
 }
