@@ -178,7 +178,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
   @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public boolean offer(E e) {
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     monitor.enter();
     try {
       boolean ok = q.offer(e);
@@ -227,7 +227,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
   @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public @Nullable E poll() {
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     monitor.enter();
     try {
       return q.poll();
@@ -239,7 +239,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
   @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public @Nullable E poll(long timeout, TimeUnit unit) throws InterruptedException {
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     if (monitor.enterWhen(notEmpty, timeout, unit)) {
       try {
         return q.poll();
@@ -254,7 +254,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
   @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public E take() throws InterruptedException {
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     monitor.enterWhen(notEmpty);
     try {
       return q.poll();
@@ -266,7 +266,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
   @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public @Nullable E peek() {
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     monitor.enter();
     try {
       return q.peek();
@@ -290,7 +290,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
   @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public int size() {
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     monitor.enter();
     try {
       return q.size();
@@ -323,7 +323,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
   @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public boolean remove(@Nullable Object o) {
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     monitor.enter();
     try {
       return q.remove(o);
@@ -343,7 +343,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
   @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public boolean contains(@Nullable Object o) {
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     monitor.enter();
     try {
       return q.contains(o);
@@ -367,7 +367,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
   @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public Object[] toArray() {
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     monitor.enter();
     try {
       return q.toArray();
@@ -408,7 +408,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
   @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public <T> T[] toArray(T[] a) {
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     monitor.enter();
     try {
       return q.toArray(a);
@@ -420,7 +420,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
   @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public String toString() {
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     monitor.enter();
     try {
       return q.toString();
@@ -440,7 +440,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
   public int drainTo(Collection<? super E> c) {
     if (c == null) throw new NullPointerException();
     if (c == this) throw new IllegalArgumentException();
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     monitor.enter();
     try {
       int n = 0;
@@ -467,7 +467,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
     if (c == null) throw new NullPointerException();
     if (c == this) throw new IllegalArgumentException();
     if (maxElements <= 0) return 0;
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     monitor.enter();
     try {
       int n = 0;
@@ -488,7 +488,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
    */
   @Override
   public void clear() {
-    final Monitor monitor = this.monitor;
+    Monitor monitor = this.monitor;
     monitor.enter();
     try {
       q.clear();
