@@ -51,7 +51,7 @@ import org.jspecify.annotations.NullMarked;
  * @author Jared Levy
  */
 @J2ktIncompatible // EnumBimap
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @NullMarked
 public class EnumBiMapTest extends TestCase {
   private enum Currency {
@@ -291,9 +291,9 @@ public class EnumBiMapTest extends TestCase {
     assertEquals(3, uniqueEntries.size());
   }
 
+  @GwtIncompatible
   @J2ktIncompatible
-  @GwtIncompatible // serialization
-  public void testSerializable() {
+    public void testSerializable() {
     SerializableTester.reserializeAndAssert(
         EnumBiMap.create(ImmutableMap.of(Currency.DOLLAR, Country.CANADA)));
   }
