@@ -50,7 +50,7 @@ import org.jspecify.annotations.Nullable;
  *
  * @author Jared Levy
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @NullMarked
 public class ImmutableListMultimapTest extends TestCase {
   @J2ktIncompatible
@@ -153,7 +153,7 @@ public class ImmutableListMultimapTest extends TestCase {
 
   public void testBuilder_withMutableEntry() {
     ImmutableListMultimap.Builder<String, Integer> builder = new Builder<>();
-    final StringHolder holder = new StringHolder();
+    StringHolder holder = new StringHolder();
     holder.string = "one";
     Entry<String, Integer> entry =
         new AbstractMapEntry<String, Integer>() {
