@@ -49,6 +49,7 @@ import java.io.ByteArrayOutputStream;
 import java.io.ObjectOutputStream;
 import java.io.Serializable;
 import java.util.AbstractMap;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.LinkedHashMap;
@@ -70,7 +71,7 @@ import org.jspecify.annotations.Nullable;
  * @author Kevin Bourrillion
  * @author Jesse Wilson
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @SuppressWarnings("AlwaysThrows")
 @NullMarked
 public class ImmutableMapTest extends TestCase {
@@ -300,7 +301,7 @@ public class ImmutableMapTest extends TestCase {
 
   public void testBuilder_withMutableEntry() {
     ImmutableMap.Builder<String, Integer> builder = new Builder<>();
-    final StringHolder holder = new StringHolder();
+    StringHolder holder = new StringHolder();
     holder.string = "one";
     Entry<String, Integer> entry =
         new AbstractMapEntry<String, Integer>() {
@@ -857,9 +858,9 @@ public class ImmutableMapTest extends TestCase {
   }
 
   private static class IntHolder implements Serializable {
-    public int value;
+    private int value;
 
-    public IntHolder(int value) {
+    IntHolder(int value) {
       this.value = value;
     }
 
@@ -895,7 +896,7 @@ public class ImmutableMapTest extends TestCase {
     LenientSerializableTester.reserializeAndAssertLenient(map.keySet());
 
     Collection<Integer> reserializedValues = reserialize(map.values());
-    assertEquals(Lists.newArrayList(map.values()), Lists.newArrayList(reserializedValues));
+    assertEquals(new ArrayList<>(map.values()), new ArrayList<>(reserializedValues));
     assertTrue(reserializedValues instanceof ImmutableCollection);
   }
 
