@@ -61,12 +61,15 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.Comparator;
 import java.util.ConcurrentModificationException;
 import java.util.Enumeration;
 import java.util.Iterator;
+import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.ListIterator;
 import java.util.NoSuchElementException;
+import java.util.Objects;
 import java.util.RandomAccess;
 import java.util.Set;
 import java.util.Vector;
@@ -82,7 +85,7 @@ import org.jspecify.annotations.Nullable;
  *
  * @author Kevin Bourrillion
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @NullMarked
 public class IteratorsTest extends TestCase {
 
@@ -284,8 +287,8 @@ public class IteratorsTest extends TestCase {
 
   @GwtIncompatible // unreasonably slow
   public void testFilterUsingIteratorTester() {
-    final List<Integer> list = asList(1, 2, 3, 4, 5);
-    final Predicate<Integer> isEven =
+    List<Integer> list = asList(1, 2, 3, 4, 5);
+    Predicate<Integer> isEven =
         new Predicate<Integer>() {
           @Override
           public boolean apply(Integer integer) {
@@ -302,7 +305,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testAny() {
-    List<String> list = Lists.newArrayList();
+    List<String> list = new ArrayList<>();
     Predicate<String> predicate = equalTo("pants");
 
     assertFalse(any(list.iterator(), predicate));
@@ -313,7 +316,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testAll() {
-    List<String> list = Lists.newArrayList();
+    List<String> list = new ArrayList<>();
     Predicate<String> predicate = equalTo("cool");
 
     assertTrue(all(list.iterator(), predicate));
@@ -781,7 +784,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testConcatNested_appendToEnd() {
-    final int nestingDepth = 128;
+    int nestingDepth = 128;
     Iterator<Integer> iterator = iterateOver();
     for (int i = 0; i < nestingDepth; i++) {
       iterator = Iterators.concat(iterator, iterateOver(1));
@@ -790,7 +793,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testConcatNested_appendToBeginning() {
-    final int nestingDepth = 128;
+    int nestingDepth = 128;
     Iterator<Integer> iterator = iterateOver();
     for (int i = 0; i < nestingDepth; i++) {
       iterator = Iterators.concat(iterateOver(1), iterator);
@@ -817,7 +820,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testAddAllToSet() {
-    Set<String> alreadyThere = Sets.newLinkedHashSet(asList("already", "there"));
+    Set<String> alreadyThere = new LinkedHashSet<>(asList("already", "there"));
     List<String> oneMore = Lists.newArrayList("there");
 
     boolean changed = Iterators.addAll(alreadyThere, oneMore.iterator());
@@ -834,21 +837,21 @@ public class IteratorsTest extends TestCase {
 
   @GwtIncompatible // Only used by @GwtIncompatible code
   private abstract static class EmptyIteratorTester extends IteratorTester<Integer> {
-    protected EmptyIteratorTester() {
+    EmptyIteratorTester() {
       super(3, MODIFIABLE, Collections.<Integer>emptySet(), IteratorTester.KnownOrder.KNOWN_ORDER);
     }
   }
 
   @GwtIncompatible // Only used by @GwtIncompatible code
   private abstract static class SingletonIteratorTester extends IteratorTester<Integer> {
-    protected SingletonIteratorTester() {
+    SingletonIteratorTester() {
       super(3, MODIFIABLE, singleton(1), IteratorTester.KnownOrder.KNOWN_ORDER);
     }
   }
 
   @GwtIncompatible // Only used by @GwtIncompatible code
   private abstract static class DoubletonIteratorTester extends IteratorTester<Integer> {
-    protected DoubletonIteratorTester() {
+    DoubletonIteratorTester() {
       super(5, MODIFIABLE, newArrayList(1, 2), IteratorTester.KnownOrder.KNOWN_ORDER);
     }
   }
@@ -863,7 +866,7 @@ public class IteratorsTest extends TestCase {
     Iterable<?> b;
 
     // Base case.
-    a = Lists.newArrayList();
+    a = new ArrayList<>();
     b = emptySet();
     assertTrue(elementsEqual(a.iterator(), b.iterator()));
 
@@ -1183,7 +1186,7 @@ public class IteratorsTest extends TestCase {
 
   @SuppressWarnings("JUnitIncompatibleType") // Fails with j2kt.
   public void testLimit() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     assertThrows(IllegalArgumentException.class, () -> Iterators.limit(list.iterator(), -1));
 
     assertFalse(Iterators.limit(list.iterator(), 0).hasNext());
@@ -1202,7 +1205,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testLimitRemove() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     list.add("cool");
     list.add("pants");
     Iterator<String> iterator = Iterators.limit(list.iterator(), 1);
@@ -1215,12 +1218,12 @@ public class IteratorsTest extends TestCase {
 
   @GwtIncompatible // fairly slow (~30s)
   public void testLimitUsingIteratorTester() {
-    final List<Integer> list = Lists.newArrayList(1, 2, 3, 4, 5);
+    List<Integer> list = Lists.newArrayList(1, 2, 3, 4, 5);
     new IteratorTester<Integer>(
         5, MODIFIABLE, newArrayList(1, 2, 3), IteratorTester.KnownOrder.KNOWN_ORDER) {
       @Override
       protected Iterator<Integer> newTargetIterator() {
-        return Iterators.limit(Lists.newArrayList(list).iterator(), 3);
+        return Iterators.limit(new ArrayList<>(list).iterator(), 3);
       }
     }.test();
   }
@@ -1246,14 +1249,14 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testGetLast_basic() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     list.add("a");
     list.add("b");
     assertEquals("b", getLast(list.iterator()));
   }
 
   public void testGetLast_exception() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     assertThrows(NoSuchElementException.class, () -> getLast(list.iterator()));
   }
 
@@ -1278,7 +1281,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testGet_basic() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     list.add("a");
     list.add("b");
     Iterator<String> iterator = list.iterator();
@@ -1287,7 +1290,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testGet_atSize() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     list.add("a");
     list.add("b");
     Iterator<String> iterator = list.iterator();
@@ -1296,7 +1299,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testGet_pastEnd() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     list.add("a");
     list.add("b");
     Iterator<String> iterator = list.iterator();
@@ -1305,7 +1308,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testGet_empty() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     Iterator<String> iterator = list.iterator();
     assertThrows(IndexOutOfBoundsException.class, () -> get(iterator, 0));
     assertFalse(iterator.hasNext());
@@ -1318,7 +1321,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testGet_withDefault_basic() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     list.add("a");
     list.add("b");
     Iterator<String> iterator = list.iterator();
@@ -1327,7 +1330,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testGet_withDefault_atSize() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     list.add("a");
     list.add("b");
     Iterator<String> iterator = list.iterator();
@@ -1336,7 +1339,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testGet_withDefault_pastEnd() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     list.add("a");
     list.add("b");
     Iterator<String> iterator = list.iterator();
@@ -1345,7 +1348,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testGet_withDefault_negativeIndex() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     list.add("a");
     list.add("b");
     Iterator<String> iterator = list.iterator();
@@ -1354,7 +1357,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testAdvance_basic() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     list.add("a");
     list.add("b");
     Iterator<String> iterator = list.iterator();
@@ -1363,7 +1366,7 @@ public class IteratorsTest extends TestCase {
   }
 
   public void testAdvance_pastEnd() {
-    List<String> list = newArrayList();
+    List<String> list = new ArrayList<>();
     list.add("a");
     list.add("b");
     Iterator<String> iterator = list.iterator();
@@ -1444,8 +1447,8 @@ public class IteratorsTest extends TestCase {
     return ListTestSuiteBuilder.using(
             new TestStringListGenerator() {
               @Override
-              public List<String> create(final String[] elements) {
-                final List<String> delegate = newArrayList(elements);
+              public List<String> create(String[] elements) {
+                List<String> delegate = newArrayList(elements);
                 return new ForwardingList<String>() {
                   @Override
                   protected List<String> delegate() {
@@ -1545,4 +1548,76 @@ public class IteratorsTest extends TestCase {
     assertSame(peek, Iterators.peekingIterator(peek));
     assertSame(peek, Iterators.peekingIterator((Iterator<String>) peek));
   }
+
+  public void testMergeSorted_stable_issue5773Example() {
+    ImmutableList<TestDatum> left = ImmutableList.of(new TestDatum("B", 1), new TestDatum("C", 1));
+    ImmutableList<TestDatum> right = ImmutableList.of(new TestDatum("A", 2), new TestDatum("C", 2));
+
+    Comparator<TestDatum> comparator = Comparator.comparing(d -> d.letter);
+
+    // When elements compare as equal (both C's have same letter), our merge should always return C1
+    // before C2, since C1 is from the first iterator.
+
+    Iterator<TestDatum> merged =
+        Iterators.mergeSorted(ImmutableList.of(left.iterator(), right.iterator()), comparator);
+
+    ImmutableList<TestDatum> result = ImmutableList.copyOf(merged);
+
+    assertThat(result)
+        .containsExactly(
+            new TestDatum("A", 2),
+            new TestDatum("B", 1),
+            new TestDatum("C", 1),
+            new TestDatum("C", 2))
+        .inOrder();
+  }
+
+  public void testMergeSorted_stable_allEqual() {
+    ImmutableList<TestDatum> first = ImmutableList.of(new TestDatum("A", 1), new TestDatum("A", 2));
+    ImmutableList<TestDatum> second =
+        ImmutableList.of(new TestDatum("A", 3), new TestDatum("A", 4));
+
+    Comparator<TestDatum> comparator = Comparator.comparing(d -> d.letter);
+    Iterator<TestDatum> merged =
+        Iterators.mergeSorted(ImmutableList.of(first.iterator(), second.iterator()), comparator);
+
+    ImmutableList<TestDatum> result = ImmutableList.copyOf(merged);
+
+    assertThat(result)
+        .containsExactly(
+            new TestDatum("A", 1),
+            new TestDatum("A", 2),
+            new TestDatum("A", 3),
+            new TestDatum("A", 4))
+        .inOrder();
+  }
+
+  private static final class TestDatum {
+    final String letter;
+    final int number;
+
+    TestDatum(String letter, int number) {
+      this.letter = letter;
+      this.number = number;
+    }
+
+    @Override
+    public String toString() {
+      return letter + number;
+    }
+
+    @Override
+    public boolean equals(@Nullable Object o) {
+      if (!(o instanceof TestDatum)) {
+        return false;
+      }
+      TestDatum other = (TestDatum) o;
+      return letter.equals(other.letter) && number == other.number;
+    }
+
+    @Override
+    public int hashCode() {
+      return Objects.hash(letter, number);
+    }
+  }
 }
