@@ -21,7 +21,6 @@ import static com.google.common.collect.Maps.immutableEntry;
 import static com.google.common.collect.Multimaps.synchronizedMultimap;
 import static com.google.common.collect.ReflectionFreeAssertThrows.assertThrows;
 import static com.google.common.collect.Sets.newHashSet;
-import static com.google.common.collect.Sets.newLinkedHashSet;
 import static com.google.common.collect.testing.Helpers.mapEntry;
 import static com.google.common.collect.testing.IteratorFeature.MODIFIABLE;
 import static com.google.common.truth.Truth.assertThat;
@@ -38,8 +37,11 @@ import com.google.common.collect.testing.google.SetMultimapTestSuiteBuilder;
 import com.google.common.collect.testing.google.TestStringSetMultimapGenerator;
 import com.google.common.testing.EqualsTester;
 import com.google.common.testing.SerializableTester;
+import java.util.ArrayList;
 import java.util.Collection;
+import java.util.HashSet;
 import java.util.Iterator;
+import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map.Entry;
 import java.util.Set;
@@ -54,7 +56,7 @@ import org.jspecify.annotations.Nullable;
  *
  * @author Jared Levy
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @NullMarked
 public class LinkedHashMultimapTest extends TestCase {
 
@@ -108,8 +110,8 @@ public class LinkedHashMultimapTest extends TestCase {
     }
   }
 
-  private Multimap<String, Integer> initializeMultimap5() {
-    Multimap<String, Integer> multimap = LinkedHashMultimap.create();
+  private SetMultimap<String, Integer> initializeMultimap5() {
+    SetMultimap<String, Integer> multimap = LinkedHashMultimap.create();
     multimap.put("foo", 5);
     multimap.put("bar", 4);
     multimap.put("foo", 3);
@@ -119,7 +121,7 @@ public class LinkedHashMultimapTest extends TestCase {
   }
 
   public void testToString() {
-    Multimap<String, Integer> multimap = LinkedHashMultimap.create();
+    SetMultimap<String, Integer> multimap = LinkedHashMultimap.create();
     multimap.put("foo", 3);
     multimap.put("bar", 1);
     multimap.putAll("foo", asList(-1, 2, 4));
@@ -129,33 +131,33 @@ public class LinkedHashMultimapTest extends TestCase {
   }
 
   public void testOrderingReadOnly() {
-    Multimap<String, Integer> multimap = initializeMultimap5();
+    SetMultimap<String, Integer> multimap = initializeMultimap5();
     assertOrderingReadOnly(multimap);
   }
 
   public void testOrderingUnmodifiable() {
-    Multimap<String, Integer> multimap = initializeMultimap5();
+    SetMultimap<String, Integer> multimap = initializeMultimap5();
     assertOrderingReadOnly(Multimaps.unmodifiableMultimap(multimap));
   }
 
   @J2ktIncompatible // Synchronized
   public void testOrderingSynchronized() {
-    Multimap<String, Integer> multimap = initializeMultimap5();
+    SetMultimap<String, Integer> multimap = initializeMultimap5();
     assertOrderingReadOnly(synchronizedMultimap(multimap));
   }
 
   @J2ktIncompatible
   @GwtIncompatible // SeriazableTester
   public void testSerializationOrdering() {
-    Multimap<String, Integer> multimap = initializeMultimap5();
-    Multimap<String, Integer> copy = SerializableTester.reserializeAndAssert(multimap);
+    SetMultimap<String, Integer> multimap = initializeMultimap5();
+    SetMultimap<String, Integer> copy = SerializableTester.reserializeAndAssert(multimap);
     assertOrderingReadOnly(copy);
   }
 
   @J2ktIncompatible
   @GwtIncompatible // SeriazableTester
   public void testSerializationOrderingKeysAndEntries() {
-    Multimap<String, Integer> multimap = LinkedHashMultimap.create();
+    SetMultimap<String, Integer> multimap = LinkedHashMultimap.create();
     multimap.put("a", 1);
     multimap.put("b", 2);
     multimap.put("a", 3);
@@ -198,7 +200,7 @@ public class LinkedHashMultimapTest extends TestCase {
   }
 
   public void testOrderingUpdates() {
-    Multimap<String, Integer> multimap = initializeMultimap5();
+    SetMultimap<String, Integer> multimap = initializeMultimap5();
 
     assertThat(multimap.replaceValues("foo", asList(6, 7))).containsExactly(5, 3).inOrder();
     assertThat(multimap.keySet()).containsExactly("foo", "bar", "cow").inOrder();
@@ -213,7 +215,7 @@ public class LinkedHashMultimapTest extends TestCase {
   }
 
   public void testToStringNullExact() {
-    Multimap<@Nullable String, @Nullable Integer> multimap = LinkedHashMultimap.create();
+    SetMultimap<@Nullable String, @Nullable Integer> multimap = LinkedHashMultimap.create();
 
     multimap.put("foo", 3);
     multimap.put("foo", -1);
@@ -236,13 +238,13 @@ public class LinkedHashMultimapTest extends TestCase {
   }
 
   public void testPutMultimapOrdered() {
-    Multimap<String, Integer> multimap = LinkedHashMultimap.create();
+    SetMultimap<String, Integer> multimap = LinkedHashMultimap.create();
     multimap.putAll(initializeMultimap5());
     assertOrderingReadOnly(multimap);
   }
 
   public void testKeysToString_ordering() {
-    Multimap<String, Integer> multimap = initializeMultimap5();
+    SetMultimap<String, Integer> multimap = initializeMultimap5();
     assertEquals("[foo x 2, bar x 2, cow]", multimap.keys().toString());
   }
 
@@ -255,7 +257,7 @@ public class LinkedHashMultimapTest extends TestCase {
   }
 
   public void testCreateFromMultimap() {
-    Multimap<String, Integer> multimap = LinkedHashMultimap.create();
+    SetMultimap<String, Integer> multimap = LinkedHashMultimap.create();
     multimap.put("a", 1);
     multimap.put("b", 2);
     multimap.put("a", 3);
@@ -283,9 +285,9 @@ public class LinkedHashMultimapTest extends TestCase {
     new IteratorTester<Integer>(
         6,
         MODIFIABLE,
-        newLinkedHashSet(asList(2, 3, 4, 7, 8)),
+        new LinkedHashSet<>(asList(2, 3, 4, 7, 8)),
         IteratorTester.KnownOrder.KNOWN_ORDER) {
-      private @Nullable Multimap<String, Integer> multimap;
+      private @Nullable SetMultimap<String, Integer> multimap;
 
       @Override
       protected Iterator<Integer> newTargetIterator() {
@@ -298,7 +300,7 @@ public class LinkedHashMultimapTest extends TestCase {
 
       @Override
       protected void verify(List<Integer> elements) {
-        assertEquals(newHashSet(elements), multimap.get("foo"));
+        assertEquals(new HashSet<>(elements), multimap.get("foo"));
       }
     }.test();
   }
@@ -306,7 +308,7 @@ public class LinkedHashMultimapTest extends TestCase {
   @GwtIncompatible // unreasonably slow
   public void testEntriesIteration() {
     Set<Entry<String, Integer>> set =
-        Sets.newLinkedHashSet(
+        new LinkedHashSet<>(
             asList(
                 immutableEntry("foo", 2),
                 immutableEntry("foo", 3),
@@ -316,7 +318,7 @@ public class LinkedHashMultimapTest extends TestCase {
 
     new IteratorTester<Entry<String, Integer>>(
         6, MODIFIABLE, set, IteratorTester.KnownOrder.KNOWN_ORDER) {
-      private @Nullable Multimap<String, Integer> multimap;
+      private @Nullable SetMultimap<String, Integer> multimap;
 
       @Override
       protected Iterator<Entry<String, Integer>> newTargetIterator() {
@@ -329,7 +331,7 @@ public class LinkedHashMultimapTest extends TestCase {
 
       @Override
       protected void verify(List<Entry<String, Integer>> elements) {
-        assertEquals(newHashSet(elements), multimap.entries());
+        assertEquals(new HashSet<>(elements), multimap.entries());
       }
     }.test();
   }
@@ -341,7 +343,7 @@ public class LinkedHashMultimapTest extends TestCase {
         MODIFIABLE,
         newArrayList("foo", "foo", "bar", "bar", "foo"),
         IteratorTester.KnownOrder.KNOWN_ORDER) {
-      private @Nullable Multimap<String, Integer> multimap;
+      private @Nullable SetMultimap<String, Integer> multimap;
 
       @Override
       protected Iterator<String> newTargetIterator() {
@@ -354,7 +356,7 @@ public class LinkedHashMultimapTest extends TestCase {
 
       @Override
       protected void verify(List<String> elements) {
-        assertEquals(elements, Lists.newArrayList(multimap.keys()));
+        assertEquals(elements, new ArrayList<>(multimap.keys()));
       }
     }.test();
   }
@@ -363,7 +365,7 @@ public class LinkedHashMultimapTest extends TestCase {
   public void testValuesIteration() {
     new IteratorTester<Integer>(
         6, MODIFIABLE, newArrayList(2, 3, 4, 5, 6), IteratorTester.KnownOrder.KNOWN_ORDER) {
-      private @Nullable Multimap<String, Integer> multimap;
+      private @Nullable SetMultimap<String, Integer> multimap;
 
       @Override
       protected Iterator<Integer> newTargetIterator() {
@@ -376,7 +378,7 @@ public class LinkedHashMultimapTest extends TestCase {
 
       @Override
       protected void verify(List<Integer> elements) {
-        assertEquals(elements, Lists.newArrayList(multimap.values()));
+        assertEquals(elements, new ArrayList<>(multimap.values()));
       }
     }.test();
   }
@@ -386,9 +388,9 @@ public class LinkedHashMultimapTest extends TestCase {
     new IteratorTester<String>(
         6,
         MODIFIABLE,
-        newLinkedHashSet(asList("foo", "bar", "baz", "dog", "cat")),
+        new LinkedHashSet<>(asList("foo", "bar", "baz", "dog", "cat")),
         IteratorTester.KnownOrder.KNOWN_ORDER) {
-      private @Nullable Multimap<String, Integer> multimap;
+      private @Nullable SetMultimap<String, Integer> multimap;
 
       @Override
       protected Iterator<String> newTargetIterator() {
@@ -405,7 +407,7 @@ public class LinkedHashMultimapTest extends TestCase {
 
       @Override
       protected void verify(List<String> elements) {
-        assertEquals(newHashSet(elements), multimap.keySet());
+        assertEquals(new HashSet<>(elements), multimap.keySet());
       }
     }.test();
   }
@@ -413,7 +415,7 @@ public class LinkedHashMultimapTest extends TestCase {
   @GwtIncompatible // unreasonably slow
   public void testAsSetIteration() {
     Set<Entry<String, Collection<Integer>>> set =
-        newLinkedHashSet(
+        new LinkedHashSet<>(
             asList(
                 immutableEntry("foo", (Collection<Integer>) newHashSet(2, 3, 6)),
                 immutableEntry("bar", (Collection<Integer>) newHashSet(4, 5, 10, 11)),
@@ -422,7 +424,7 @@ public class LinkedHashMultimapTest extends TestCase {
                 immutableEntry("cat", (Collection<Integer>) newHashSet(12, 13, 14))));
     new IteratorTester<Entry<String, Collection<Integer>>>(
         6, MODIFIABLE, set, IteratorTester.KnownOrder.KNOWN_ORDER) {
-      private @Nullable Multimap<String, Integer> multimap;
+      private @Nullable SetMultimap<String, Integer> multimap;
 
       @Override
       protected Iterator<Entry<String, Collection<Integer>>> newTargetIterator() {
@@ -439,7 +441,7 @@ public class LinkedHashMultimapTest extends TestCase {
 
       @Override
       protected void verify(List<Entry<String, Collection<Integer>>> elements) {
-        assertEquals(newHashSet(elements), multimap.asMap().entrySet());
+        assertEquals(new HashSet<>(elements), multimap.asMap().entrySet());
       }
     }.test();
   }
