@@ -26,6 +26,7 @@ import com.google.common.collect.testing.features.CollectionFeature;
 import com.google.common.collect.testing.features.CollectionSize;
 import com.google.common.collect.testing.features.MapFeature;
 import com.google.common.testing.EqualsTester;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
@@ -358,7 +359,7 @@ public class TreeRangeMapTest extends TestCase {
 
   public void testAllRangesAlone() {
     for (Range<Integer> range : RANGES) {
-      Map<Integer, Integer> model = Maps.newHashMap();
+      Map<Integer, Integer> model = new HashMap<>();
       putModel(model, range, 1);
       RangeMap<Integer, Integer> test = TreeRangeMap.create();
       test.put(range, 1);
@@ -369,7 +370,7 @@ public class TreeRangeMapTest extends TestCase {
   public void testAllRangePairs() {
     for (Range<Integer> range1 : RANGES) {
       for (Range<Integer> range2 : RANGES) {
-        Map<Integer, Integer> model = Maps.newHashMap();
+        Map<Integer, Integer> model = new HashMap<>();
         putModel(model, range1, 1);
         putModel(model, range2, 2);
         RangeMap<Integer, Integer> test = TreeRangeMap.create();
@@ -384,7 +385,7 @@ public class TreeRangeMapTest extends TestCase {
     for (Range<Integer> range1 : RANGES) {
       for (Range<Integer> range2 : RANGES) {
         for (Range<Integer> range3 : RANGES) {
-          Map<Integer, Integer> model = Maps.newHashMap();
+          Map<Integer, Integer> model = new HashMap<>();
           putModel(model, range1, 1);
           putModel(model, range2, 2);
           putModel(model, range3, 3);
@@ -402,7 +403,7 @@ public class TreeRangeMapTest extends TestCase {
     for (Range<Integer> range1 : RANGES) {
       for (Range<Integer> range2 : RANGES) {
         for (Range<Integer> range3 : RANGES) {
-          Map<Integer, Integer> model = Maps.newHashMap();
+          Map<Integer, Integer> model = new HashMap<>();
           putModel(model, range1, 1);
           putModel(model, range2, 2);
           putModel(model, range3, 3);
@@ -422,7 +423,7 @@ public class TreeRangeMapTest extends TestCase {
   public void testPutAndRemove() {
     for (Range<Integer> rangeToPut : RANGES) {
       for (Range<Integer> rangeToRemove : RANGES) {
-        Map<Integer, Integer> model = Maps.newHashMap();
+        Map<Integer, Integer> model = new HashMap<>();
         putModel(model, rangeToPut, 1);
         removeModel(model, rangeToRemove);
         RangeMap<Integer, Integer> test = TreeRangeMap.create();
@@ -437,7 +438,7 @@ public class TreeRangeMapTest extends TestCase {
     for (Range<Integer> rangeToPut1 : RANGES) {
       for (Range<Integer> rangeToPut2 : RANGES) {
         for (Range<Integer> rangeToRemove : RANGES) {
-          Map<Integer, Integer> model = Maps.newHashMap();
+          Map<Integer, Integer> model = new HashMap<>();
           putModel(model, rangeToPut1, 1);
           putModel(model, rangeToPut2, 2);
           removeModel(model, rangeToRemove);
@@ -457,7 +458,7 @@ public class TreeRangeMapTest extends TestCase {
     for (Range<Integer> rangeToPut1 : RANGES) {
       for (Range<Integer> rangeToPut2 : RANGES) {
         for (Range<Integer> rangeToRemove : RANGES) {
-          Map<Integer, Integer> model = Maps.newHashMap();
+          Map<Integer, Integer> model = new HashMap<>();
           putModel(model, rangeToPut1, 1);
           putModel(model, rangeToPut2, 2);
           removeModel(model, rangeToRemove);
