@@ -101,7 +101,7 @@ public class SourceSinkFactories {
     return new UrlCharSourceFactory();
   }
 
-  public static ByteSourceFactory asByteSourceFactory(final CharSourceFactory factory) {
+  public static ByteSourceFactory asByteSourceFactory(CharSourceFactory factory) {
     checkNotNull(factory);
     return new ByteSourceFactory() {
       @Override
@@ -121,7 +121,7 @@ public class SourceSinkFactories {
     };
   }
 
-  public static CharSourceFactory asCharSourceFactory(final ByteSourceFactory factory) {
+  public static CharSourceFactory asCharSourceFactory(ByteSourceFactory factory) {
     checkNotNull(factory);
     return new CharSourceFactory() {
       @Override
@@ -141,7 +141,7 @@ public class SourceSinkFactories {
     };
   }
 
-  public static CharSinkFactory asCharSinkFactory(final ByteSinkFactory factory) {
+  public static CharSinkFactory asCharSinkFactory(ByteSinkFactory factory) {
     checkNotNull(factory);
     return new CharSinkFactory() {
       @Override
@@ -172,7 +172,7 @@ public class SourceSinkFactories {
   }
 
   public static ByteSourceFactory asSlicedByteSourceFactory(
-      final ByteSourceFactory factory, final long off, final long len) {
+      ByteSourceFactory factory, long off, long len) {
     checkNotNull(factory);
     return new ByteSourceFactory() {
       @Override
@@ -265,16 +265,18 @@ public class SourceSinkFactories {
 
     private final ThreadLocal<File> fileThreadLocal = new ThreadLocal<>();
 
-    protected File createFile() throws IOException {
+    File createFile() throws IOException {
       File file = File.createTempFile("SinkSourceFile", "txt");
       fileThreadLocal.set(file);
       return file;
     }
 
-    protected File getFile() {
+    File getFile() {
       return fileThreadLocal.get();
     }
 
+    // acts as an override in subclasses that implement SourceSinkFactory
+    @SuppressWarnings("EffectivelyPrivate")
     public final void tearDown() throws IOException {
       if (!fileThreadLocal.get().delete()) {
         logger.warning("Unable to delete file: " + fileThreadLocal.get());
