@@ -23,13 +23,13 @@ import com.google.common.base.Function;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
-import com.google.common.collect.Maps;
 import com.google.common.primitives.Primitives;
 import com.google.common.testing.EqualsTester;
 import com.google.common.testing.NullPointerTester;
 import com.google.common.testing.SerializableTester;
 import com.google.common.truth.IterableSubject;
 import com.google.errorprone.annotations.CanIgnoreReturnValue;
+import com.google.errorprone.annotations.Keep;
 import java.io.Serializable;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Field;
@@ -42,6 +42,7 @@ import java.lang.reflect.WildcardType;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import junit.framework.TestCase;
@@ -550,7 +551,7 @@ public class TypeTokenTest extends TestCase {
   }
 
   public void testGetGenericInterfaces_withInterfaces() {
-    Map<Class<?>, Type> interfaceMap = Maps.newHashMap();
+    Map<Class<?>, Type> interfaceMap = new HashMap<>();
     for (TypeToken<?> interfaceType :
         new TypeToken<Implementation<Integer, String>>() {}.getGenericInterfaces()) {
       interfaceMap.put(interfaceType.getRawType(), interfaceType.getType());
@@ -1068,10 +1069,9 @@ public class TypeTokenTest extends TestCase {
     assertThat(parameterizedType.getOwnerType()).isEqualTo(javacReturnType.getOwnerType());
   }
 
-  public static <T> GenericClass<T> getStaticAnonymousClass(final T value) {
+  public static <T> GenericClass<T> getStaticAnonymousClass(T value) {
     return new GenericClass<T>() {
-      @SuppressWarnings("unused")
-      public T innerValue = value;
+      @Keep public final T innerValue = value;
     };
   }
 
@@ -1442,8 +1442,7 @@ public class TypeTokenTest extends TestCase {
   public void testGetSubtype_subtypeSameAsDeclaringType() throws Exception {
     class Bar<T> {}
     class SubBar<T> extends Bar<T> {
-      @SuppressWarnings("unused")
-      Bar<T> delegate;
+      @Keep Bar<T> delegate;
 
       TypeToken<SubBar<T>> fieldTypeAsSubBar() {
         return new TypeToken<SubBar<T>>() {};
@@ -1476,7 +1475,7 @@ public class TypeTokenTest extends TestCase {
     assertEquals(int[].class, arrayOf(int.class).getRawType());
   }
 
-  @SuppressWarnings("unused") // used by reflection
+  @Keep
   private static class Holder<T> {
     List<T>[] matrix;
 
@@ -1530,8 +1529,7 @@ public class TypeTokenTest extends TestCase {
   }
 
   private static class Counter<N extends Number> {
-    @SuppressWarnings("unused") // used by reflection
-    List<N> counts;
+    @Keep List<N> counts;
   }
 
   public void testWildcardCaptured_typeVariableDeclaresTypeBound_wildcardHasNoExplicitUpperBound()
@@ -1685,7 +1683,7 @@ public class TypeTokenTest extends TestCase {
   }
 
   private static class Container<T> {
-    @SuppressWarnings("unused")
+    @Keep
     public Container(T data) {}
   }
 
@@ -1700,7 +1698,7 @@ public class TypeTokenTest extends TestCase {
   }
 
   private static class CannotConstruct<E extends Throwable> {
-    @SuppressWarnings("unused")
+    @Keep
     public CannotConstruct() throws E {}
   }
 
@@ -1748,7 +1746,6 @@ public class TypeTokenTest extends TestCase {
     }
   }
 
-  @SuppressWarnings("RestrictedApiChecker") // crashes under JDK8, which EP no longer supports
   public <T> void testRejectTypeVariable_withOwnerType() {
     // Neither has subclass
     assertHasTypeVariable(new From<Integer>().new To<String>().type());
