@@ -510,7 +510,7 @@ abstract class JSR166TestCase extends TestCase {
     long startTime = System.nanoTime();
     try {
       future.get(timeoutMillis, MILLISECONDS);
-      shouldThrow();
+      fail("Should throw exception");
     } catch (TimeoutException success) {
     } catch (Exception e) {
       threadUnexpectedException(e);
@@ -520,16 +520,6 @@ abstract class JSR166TestCase extends TestCase {
     assertTrue(millisElapsedSince(startTime) >= timeoutMillis);
   }
 
-  /** Fails with message "should throw exception". */
-  public void shouldThrow() {
-    fail("Should throw exception");
-  }
-
-  /** Fails with message "should throw " + exceptionName. */
-  public void shouldThrow(String exceptionName) {
-    fail("Should throw " + exceptionName);
-  }
-
   /** The number of elements to place in collections, arrays, etc. */
   public static final int SIZE = 20;
 
@@ -849,7 +839,7 @@ abstract class JSR166TestCase extends TestCase {
     }
   }
 
-  public Callable<String> latchAwaitingStringTask(final CountDownLatch latch) {
+  public Callable<String> latchAwaitingStringTask(CountDownLatch latch) {
     return new CheckedCallable<String>() {
       @Override
       protected String realCall() {
@@ -862,7 +852,7 @@ abstract class JSR166TestCase extends TestCase {
     };
   }
 
-  public Runnable awaiter(final CountDownLatch latch) {
+  public Runnable awaiter(CountDownLatch latch) {
     return new CheckedRunnable() {
       @Override
       public void realRun() throws InterruptedException {
@@ -973,7 +963,7 @@ abstract class JSR166TestCase extends TestCase {
     }
   }
 
-  public Runnable possiblyInterruptedRunnable(final long timeoutMillis) {
+  public Runnable possiblyInterruptedRunnable(long timeoutMillis) {
     return new CheckedRunnable() {
       @Override
       protected void realRun() {
@@ -1017,7 +1007,7 @@ abstract class JSR166TestCase extends TestCase {
     boolean isDone();
   }
 
-  public static TrackedRunnable trackedRunnable(final long timeoutMillis) {
+  public static TrackedRunnable trackedRunnable(long timeoutMillis) {
     return new TrackedRunnable() {
       private volatile boolean done = false;
 
@@ -1184,17 +1174,17 @@ abstract class JSR166TestCase extends TestCase {
       assertFalse(q.iterator().hasNext());
       try {
         q.element();
-        shouldThrow();
+        fail("Should throw exception");
       } catch (NoSuchElementException success) {
       }
       try {
         q.iterator().next();
-        shouldThrow();
+        fail("Should throw exception");
       } catch (NoSuchElementException success) {
       }
       try {
         q.remove();
-        shouldThrow();
+        fail("Should throw exception");
       } catch (NoSuchElementException success) {
       }
     } catch (InterruptedException ie) {
