@@ -26,6 +26,7 @@ import static com.google.common.util.concurrent.Uninterruptibles.takeUninterrupt
 import static com.google.common.util.concurrent.Uninterruptibles.tryAcquireUninterruptibly;
 import static com.google.common.util.concurrent.Uninterruptibles.tryLockUninterruptibly;
 import static java.util.concurrent.Executors.newFixedThreadPool;
+import static java.util.concurrent.Executors.newScheduledThreadPool;
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
 import static java.util.concurrent.TimeUnit.SECONDS;
 
@@ -41,7 +42,6 @@ import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.Semaphore;
@@ -693,7 +693,7 @@ public class UninterruptiblesTest extends TestCase {
   private abstract static class DelayedActionRunnable implements Runnable {
     private final long tMinus;
 
-    protected DelayedActionRunnable(long tMinus) {
+    DelayedActionRunnable(long tMinus) {
       this.tMinus = tMinus;
     }
 
@@ -707,13 +707,13 @@ public class UninterruptiblesTest extends TestCase {
       doAction();
     }
 
-    protected abstract void doAction();
+    abstract void doAction();
   }
 
   private static class CountDown extends DelayedActionRunnable {
     private final CountDownLatch latch;
 
-    public CountDown(CountDownLatch latch, long tMinus) {
+    CountDown(CountDownLatch latch, long tMinus) {
       super(tMinus);
       this.latch = latch;
     }
@@ -727,7 +727,7 @@ public class UninterruptiblesTest extends TestCase {
   private static class EnableWrites extends DelayedActionRunnable {
     private final BlockingQueue<String> queue;
 
-    public EnableWrites(BlockingQueue<String> queue, long tMinus) {
+    EnableWrites(BlockingQueue<String> queue, long tMinus) {
       super(tMinus);
       assertFalse(queue.isEmpty());
       assertFalse(queue.offer("shouldBeRejected"));
@@ -743,7 +743,7 @@ public class UninterruptiblesTest extends TestCase {
   private static class EnableReads extends DelayedActionRunnable {
     private final BlockingQueue<String> queue;
 
-    public EnableReads(BlockingQueue<String> queue, long tMinus) {
+    EnableReads(BlockingQueue<String> queue, long tMinus) {
       super(tMinus);
       assertTrue(queue.isEmpty());
       this.queue = queue;
@@ -789,7 +789,7 @@ public class UninterruptiblesTest extends TestCase {
   }
 
   private static class JoinTarget extends DelayedActionRunnable {
-    public JoinTarget(long tMinus) {
+    JoinTarget(long tMinus) {
       super(tMinus);
     }
 
@@ -800,7 +800,7 @@ public class UninterruptiblesTest extends TestCase {
   private static class Release extends DelayedActionRunnable {
     private final Semaphore semaphore;
 
-    public Release(Semaphore semaphore, long tMinus) {
+    Release(Semaphore semaphore, long tMinus) {
       super(tMinus);
       this.semaphore = semaphore;
     }
@@ -856,8 +856,8 @@ public class UninterruptiblesTest extends TestCase {
   }
 
   @CanIgnoreReturnValue
-  private static Thread acquireFor(final Lock lock, final long duration, final TimeUnit unit) {
-    final CountDownLatch latch = new CountDownLatch(1);
+  private static Thread acquireFor(Lock lock, long duration, TimeUnit unit) {
+    CountDownLatch latch = new CountDownLatch(1);
     Thread thread =
         new Thread() {
           @Override
@@ -889,9 +889,9 @@ public class UninterruptiblesTest extends TestCase {
     }
 
     static TestCondition createAndSignalAfter(long delay, TimeUnit unit) {
-      final TestCondition testCondition = create();
+      TestCondition testCondition = create();
 
-      ScheduledExecutorService scheduledPool = Executors.newScheduledThreadPool(1);
+      ScheduledExecutorService scheduledPool = newScheduledThreadPool(1);
       // If signal() fails somehow, we should see a failed test, even without looking at the Future.
       Future<?> unused =
           scheduledPool.schedule(
