@@ -98,7 +98,7 @@ import org.jspecify.annotations.Nullable;
  * @author Louis Wasserman
  * @since 1.0
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 public final class Splitter {
   private final CharMatcher trimmer;
   private final boolean omitEmptyStrings;
@@ -418,7 +418,6 @@ public final class Splitter {
    * @return a stream over the segments split from the parameter
    * @since 33.4.0 (but since 28.2 in the JRE flavor)
    */
-  @SuppressWarnings("Java7ApiChecker")
   // If users use this when they shouldn't, we hope that NewApi will catch subsequent Stream calls.
   @IgnoreJRERequirement
   public Stream<String> splitToStream(CharSequence sequence) {
@@ -541,7 +540,7 @@ public final class Splitter {
     int offset = 0;
     int limit;
 
-    protected SplittingIterator(Splitter splitter, CharSequence toSplit) {
+    SplittingIterator(Splitter splitter, CharSequence toSplit) {
       this.trimmer = splitter.trimmer;
       this.omitEmptyStrings = splitter.omitEmptyStrings;
       this.limit = splitter.limit;
