@@ -40,7 +40,6 @@ import org.jspecify.annotations.Nullable;
 
 /** Collectors utilities for {@code common.collect} internals. */
 @GwtCompatible
-@SuppressWarnings("Java7ApiChecker")
 @IgnoreJRERequirement // used only from APIs with Java 8 types in them
 final class CollectCollectors {
 
@@ -312,7 +311,7 @@ final class CollectCollectors {
   }
 
   @IgnoreJRERequirement // see enclosing class (whose annotation Animal Sniffer ignores here...)
-  private static class EnumMapAccumulator<K extends Enum<K>, V> {
+  private static final class EnumMapAccumulator<K extends Enum<K>, V> {
     private final BinaryOperator<V> mergeFunction;
     private @Nullable EnumMap<K, V> map = null;
 
