@@ -37,7 +37,6 @@ import org.jspecify.annotations.Nullable;
 
 /** Spliterator utilities for {@code common.collect} internals. */
 @GwtCompatible
-@SuppressWarnings("Java7ApiChecker")
 @IgnoreJRERequirement // used only from APIs that work with Stream
 final class CollectSpliterators {
   private CollectSpliterators() {}
@@ -61,7 +60,7 @@ final class CollectSpliterators {
      * processes Streams and thus hasn't had a chance to see Streams's annotation?
      */
     @IgnoreJRERequirement
-    class WithCharacteristics implements Spliterator<T> {
+    final class WithCharacteristics implements Spliterator<T> {
       private final Spliterator.OfInt delegate;
 
       WithCharacteristics(Spliterator.OfInt delegate) {
@@ -157,7 +156,7 @@ final class CollectSpliterators {
     checkNotNull(fromSpliterator);
     checkNotNull(predicate);
     @IgnoreJRERequirement // see earlier comment about redundancy
-    class Splitr implements Spliterator<T>, Consumer<T> {
+    final class Splitr implements Spliterator<T>, Consumer<T> {
       @Nullable T holder = null;
 
       @Override
