@@ -80,8 +80,6 @@ public final class Collections2 {
    *
    * <p><b>{@code Stream} equivalent:</b> {@link java.util.stream.Stream#filter Stream.filter}.
    */
-  // TODO(kevinb): how can we omit that Iterables link when building gwt
-  // javadoc?
   public static <E extends @Nullable Object> Collection<E> filter(
       Collection<E> unfiltered, Predicate<? super E> predicate) {
     if (unfiltered instanceof FilteredCollection) {
@@ -257,7 +255,8 @@ public final class Collections2 {
     return new TransformedCollection<>(fromCollection, function);
   }
 
-  static class TransformedCollection<F extends @Nullable Object, T extends @Nullable Object>
+  private static final class TransformedCollection<
+          F extends @Nullable Object, T extends @Nullable Object>
       extends AbstractCollection<T> {
     final Collection<F> fromCollection;
     final Function<? super F, ? extends T> function;
@@ -486,7 +485,7 @@ public final class Collections2 {
     final Comparator<? super E> comparator;
 
     OrderedPermutationIterator(List<E> list, Comparator<? super E> comparator) {
-      this.nextPermutation = Lists.newArrayList(list);
+      this.nextPermutation = new ArrayList<>(list);
       this.comparator = comparator;
     }
 
@@ -606,7 +605,7 @@ public final class Collections2 {
     }
   }
 
-  private static class PermutationIterator<E> extends AbstractIterator<List<E>> {
+  private static final class PermutationIterator<E> extends AbstractIterator<List<E>> {
     final List<E> list;
     final int[] c;
     final int[] o;
