@@ -28,7 +28,6 @@ import static java.util.Objects.requireNonNull;
 import com.google.common.annotations.GwtIncompatible;
 import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.annotations.VisibleForTesting;
-import com.google.common.base.Objects;
 import com.google.common.base.Preconditions;
 import com.google.common.primitives.Ints;
 import com.google.errorprone.annotations.CanIgnoreReturnValue;
@@ -49,6 +48,7 @@ import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.Map;
 import java.util.NoSuchElementException;
+import java.util.Objects;
 import java.util.Set;
 import org.jspecify.annotations.Nullable;
 
@@ -363,7 +363,7 @@ class CompactHashMap<K extends @Nullable Object, V extends @Nullable Object>
         entryIndex = next - 1;
         entry = entries[entryIndex];
         if (CompactHashing.getHashPrefix(entry, mask) == hashPrefix
-            && Objects.equal(key, keys[entryIndex])) {
+            && Objects.equals(key, keys[entryIndex])) {
           @SuppressWarnings("unchecked") // known to be a V
           V oldValue = (V) values[entryIndex];
 
@@ -487,7 +487,7 @@ class CompactHashMap<K extends @Nullable Object, V extends @Nullable Object>
       int entryIndex = next - 1;
       int entry = entry(entryIndex);
       if (CompactHashing.getHashPrefix(entry, mask) == hashPrefix
-          && Objects.equal(key, key(entryIndex))) {
+          && Objects.equals(key, key(entryIndex))) {
         return entryIndex;
       }
       next = CompactHashing.getNext(entry, mask);
@@ -677,7 +677,7 @@ class CompactHashMap<K extends @Nullable Object, V extends @Nullable Object>
   }
 
   @WeakOuter
-  class KeySetView extends AbstractSet<K> {
+  private final class KeySetView extends AbstractSet<K> {
     @Override
     public int size() {
       return CompactHashMap.this.size();
@@ -733,8 +733,7 @@ class CompactHashMap<K extends @Nullable Object, V extends @Nullable Object>
   }
 
   @WeakOuter
-  class EntrySetView extends AbstractSet<Entry<K, V>> {
-
+  private final class EntrySetView extends AbstractSet<Entry<K, V>> {
     @Override
     public int size() {
       return CompactHashMap.this.size();
@@ -758,7 +757,7 @@ class CompactHashMap<K extends @Nullable Object, V extends @Nullable Object>
       } else if (o instanceof Entry) {
         Entry<?, ?> entry = (Entry<?, ?>) o;
         int index = indexOf(entry.getKey());
-        return index != -1 && Objects.equal(value(index), entry.getValue());
+        return index != -1 && Objects.equals(value(index), entry.getValue());
       }
       return false;
     }
@@ -829,7 +828,7 @@ class CompactHashMap<K extends @Nullable Object, V extends @Nullable Object>
     private void updateLastKnownIndex() {
       if (lastKnownIndex == -1
           || lastKnownIndex >= size()
-          || !Objects.equal(key, key(lastKnownIndex))) {
+          || !Objects.equals(key, key(lastKnownIndex))) {
         lastKnownIndex = indexOf(key);
       }
     }
@@ -894,7 +893,7 @@ class CompactHashMap<K extends @Nullable Object, V extends @Nullable Object>
       return delegate.containsValue(value);
     }
     for (int i = 0; i < size; i++) {
-      if (Objects.equal(value, value(i))) {
+      if (Objects.equals(value, value(i))) {
         return true;
       }
     }
@@ -913,7 +912,7 @@ class CompactHashMap<K extends @Nullable Object, V extends @Nullable Object>
   }
 
   @WeakOuter
-  class ValuesView extends AbstractCollection<V> {
+  private final class ValuesView extends AbstractCollection<V> {
     @Override
     public int size() {
       return CompactHashMap.this.size();
