@@ -166,7 +166,7 @@ import org.jspecify.annotations.Nullable;
  * @since 2.0
  */
 @DoNotMock("Use ImmutableList.of or another implementation")
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @SuppressWarnings("serial") // we're overriding default serialization
 // TODO(kevinb): I think we should push everything down to "BaseImmutableCollection" or something,
 // just to do everything we can to emphasize the "practically an interface" nature of this class.
@@ -176,7 +176,6 @@ public abstract class ImmutableCollection<E> extends AbstractCollection<E> imple
    * These are properties of the collection as a whole; SIZED and SUBSIZED are more properties of
    * the spliterator implementation.
    */
-  @SuppressWarnings("Java7ApiChecker")
   // @IgnoreJRERequirement is not necessary because this compiles down to a constant.
   // (which is fortunate because Animal Sniffer doesn't look for @IgnoreJRERequirement on fields)
   static final int SPLITERATOR_CHARACTERISTICS =
@@ -189,7 +188,6 @@ public abstract class ImmutableCollection<E> extends AbstractCollection<E> imple
   public abstract UnmodifiableIterator<E> iterator();
 
   @Override
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // used only from APIs with Java 8 types in them
   // (not used within guava-android as of this writing, but we include it in the jar as a test)
   public Spliterator<E> spliterator() {
