@@ -70,7 +70,7 @@ import org.jspecify.annotations.Nullable;
  * @author Jared Levy
  * @since 2.0
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 public abstract class ImmutableMultimap<K, V> extends BaseImmutableMultimap<K, V>
     implements Serializable {
 
@@ -411,13 +411,15 @@ public abstract class ImmutableMultimap<K, V> extends BaseImmutableMultimap<K, V
   // These constants allow the deserialization code to set final fields. This
   // holder class makes sure they are not initialized unless an instance is
   // deserialized.
-  @GwtIncompatible // java serialization is not supported
+  @GwtIncompatible
   @J2ktIncompatible
-  static class FieldSettersHolder {
+  static final class FieldSettersHolder {
     static final Serialization.FieldSetter<? super ImmutableMultimap<?, ?>> MAP_FIELD_SETTER =
         Serialization.getFieldSetter(ImmutableMultimap.class, "map");
     static final Serialization.FieldSetter<? super ImmutableMultimap<?, ?>> SIZE_FIELD_SETTER =
         Serialization.getFieldSetter(ImmutableMultimap.class, "size");
+
+    private FieldSettersHolder() {}
   }
 
   ImmutableMultimap(ImmutableMap<K, ? extends ImmutableCollection<V>> map, int size) {
@@ -615,7 +617,7 @@ public abstract class ImmutableMultimap<K, V> extends BaseImmutableMultimap<K, V
     return new EntryCollection<>(this);
   }
 
-  private static class EntryCollection<K, V> extends ImmutableCollection<Entry<K, V>> {
+  private static final class EntryCollection<K, V> extends ImmutableCollection<Entry<K, V>> {
     @Weak final ImmutableMultimap<K, V> multimap;
 
     EntryCollection(ImmutableMultimap<K, V> multimap) {
@@ -704,7 +706,7 @@ public abstract class ImmutableMultimap<K, V> extends BaseImmutableMultimap<K, V
 
   @SuppressWarnings("serial") // Uses writeReplace, not default serialization
   @WeakOuter
-  class Keys extends ImmutableMultiset<K> {
+  private final class Keys extends ImmutableMultiset<K> {
     @Override
     public boolean contains(@Nullable Object object) {
       return containsKey(object);
@@ -782,7 +784,7 @@ public abstract class ImmutableMultimap<K, V> extends BaseImmutableMultimap<K, V
   @Override
   UnmodifiableIterator<V> valueIterator() {
     return new UnmodifiableIterator<V>() {
-      Iterator<? extends ImmutableCollection<V>> valueCollectionItr = map.values().iterator();
+      final Iterator<? extends ImmutableCollection<V>> valueCollectionItr = map.values().iterator();
       Iterator<V> valueItr = emptyIterator();
 
       @Override
