@@ -33,9 +33,11 @@ import com.google.common.primitives.Ints;
 import com.google.errorprone.annotations.CanIgnoreReturnValue;
 import com.google.errorprone.annotations.DoNotCall;
 import com.google.errorprone.annotations.concurrent.LazyInit;
+import com.google.j2objc.annotations.RetainedWith;
 import java.io.InvalidObjectException;
 import java.io.ObjectInputStream;
 import java.io.Serializable;
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
@@ -69,7 +71,6 @@ public final class ImmutableRangeSet<C extends Comparable> extends AbstractRange
    *
    * @since 33.2.0 (available since 23.1 in guava-jre)
    */
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // Users will use this only if they're already using streams.
   public static <E extends Comparable<? super E>>
       Collector<Range<E>, ?, ImmutableRangeSet<E>> toImmutableRangeSet() {
@@ -112,7 +113,7 @@ public final class ImmutableRangeSet<C extends Comparable> extends AbstractRange
     checkNotNull(rangeSet);
     if (rangeSet.isEmpty()) {
       return of();
-    } else if (rangeSet.encloses(Range.<C>all())) {
+    } else if (rangeSet.encloses(Range.all())) {
       return all();
     }
 
@@ -150,15 +151,17 @@ public final class ImmutableRangeSet<C extends Comparable> extends AbstractRange
   }
 
   ImmutableRangeSet(ImmutableList<Range<C>> ranges) {
-    this.ranges = ranges;
+    this(ranges, /* complement= */ null);
   }
 
-  private ImmutableRangeSet(ImmutableList<Range<C>> ranges, ImmutableRangeSet<C> complement) {
+  private ImmutableRangeSet(
+      ImmutableList<Range<C>> ranges, @Nullable ImmutableRangeSet<C> complement) {
     this.ranges = ranges;
     this.complement = complement;
   }
 
   private final transient ImmutableList<Range<C>> ranges;
+  private final transient @Nullable ImmutableRangeSet<C> complement;
 
   @Override
   public boolean intersects(Range<C> otherRange) {
@@ -306,7 +309,7 @@ public final class ImmutableRangeSet<C extends Comparable> extends AbstractRange
     if (ranges.isEmpty()) {
       return ImmutableSet.of();
     }
-    return new RegularImmutableSortedSet<>(ranges, Range.<C>rangeLexOrdering());
+    return new RegularImmutableSortedSet<>(ranges, Range.rangeLexOrdering());
   }
 
   @Override
@@ -317,9 +320,11 @@ public final class ImmutableRangeSet<C extends Comparable> extends AbstractRange
     return new RegularImmutableSortedSet<>(ranges.reverse(), Range.<C>rangeLexOrdering().reverse());
   }
 
-  @LazyInit private transient @Nullable ImmutableRangeSet<C> complement;
+  private static final class ComplementRanges<C extends Comparable>
+      extends ImmutableList<Range<C>> {
+
+    private final ImmutableList<Range<C>> ranges;
 
-  private final class ComplementRanges extends ImmutableList<Range<C>> {
     // True if the "positive" range set is empty or bounded below.
     private final boolean positiveBoundedBelow;
 
@@ -328,7 +333,8 @@ public final class ImmutableRangeSet<C extends Comparable> extends AbstractRange
 
     private final int size;
 
-    ComplementRanges() {
+    ComplementRanges(ImmutableList<Range<C>> ranges) {
+      this.ranges = ranges;
       this.positiveBoundedBelow = ranges.get(0).hasLowerBound();
       this.positiveBoundedAbove = Iterables.getLast(ranges).hasUpperBound();
 
@@ -353,14 +359,14 @@ public final class ImmutableRangeSet<C extends Comparable> extends AbstractRange
 
       Cut<C> lowerBound;
       if (positiveBoundedBelow) {
-        lowerBound = (index == 0) ? Cut.<C>belowAll() : ranges.get(index - 1).upperBound;
+        lowerBound = (index == 0) ? Cut.belowAll() : ranges.get(index - 1).upperBound;
       } else {
         lowerBound = ranges.get(index).upperBound;
       }
 
       Cut<C> upperBound;
       if (positiveBoundedAbove && index == size - 1) {
-        upperBound = Cut.<C>aboveAll();
+        upperBound = Cut.aboveAll();
       } else {
         upperBound = ranges.get(index + (positiveBoundedBelow ? 0 : 1)).lowerBound;
       }
@@ -384,18 +390,25 @@ public final class ImmutableRangeSet<C extends Comparable> extends AbstractRange
 
   @Override
   public ImmutableRangeSet<C> complement() {
-    ImmutableRangeSet<C> result = complement;
-    if (result != null) {
-      return result;
+    if (complement != null) {
+      return complement;
     } else if (ranges.isEmpty()) {
-      return complement = all();
+      return all();
     } else if (ranges.size() == 1 && ranges.get(0).equals(Range.all())) {
-      return complement = of();
+      return of();
     } else {
-      ImmutableList<Range<C>> complementRanges = new ComplementRanges();
-      result = complement = new ImmutableRangeSet<>(complementRanges, this);
+      return lazyComplement();
     }
-    return result;
+  }
+
+  @LazyInit @RetainedWith private transient @Nullable ImmutableRangeSet<C> lazyComplement;
+
+  private ImmutableRangeSet<C> lazyComplement() {
+    ImmutableRangeSet<C> result = lazyComplement;
+    return result == null
+        ? lazyComplement =
+            new ImmutableRangeSet<>(new ComplementRanges<>(ranges), /* complement= */ this)
+        : result;
   }
 
   /**
@@ -721,7 +734,7 @@ public final class ImmutableRangeSet<C extends Comparable> extends AbstractRange
     }
   }
 
-  private static class AsSetSerializedForm<C extends Comparable> implements Serializable {
+  private static final class AsSetSerializedForm<C extends Comparable> implements Serializable {
     private final ImmutableList<Range<C>> ranges;
     private final DiscreteDomain<C> domain;
 
@@ -759,7 +772,7 @@ public final class ImmutableRangeSet<C extends Comparable> extends AbstractRange
     private final List<Range<C>> ranges;
 
     public Builder() {
-      this.ranges = Lists.newArrayList();
+      this.ranges = new ArrayList<>();
     }
 
     // TODO(lowasser): consider adding union, in addition to add, that does allow overlap
@@ -816,7 +829,7 @@ public final class ImmutableRangeSet<C extends Comparable> extends AbstractRange
     public ImmutableRangeSet<C> build() {
       ImmutableList.Builder<Range<C>> mergedRangesBuilder =
           new ImmutableList.Builder<>(ranges.size());
-      sort(ranges, Range.<C>rangeLexOrdering());
+      sort(ranges, Range.rangeLexOrdering());
       PeekingIterator<Range<C>> peekingItr = Iterators.peekingIterator(ranges.iterator());
       while (peekingItr.hasNext()) {
         Range<C> range = peekingItr.next();
