@@ -59,7 +59,7 @@ import org.jspecify.annotations.Nullable;
  * @since 2.0 (implements {@code NavigableSet} since 12.0)
  */
 // TODO(benyu): benchmark and optimize all creation paths, which are a mess now
-@GwtCompatible(serializable = true, emulated = true)
+@GwtCompatible
 @SuppressWarnings("serial") // we're overriding default serialization
 public abstract class ImmutableSortedSet<E> extends ImmutableSet<E>
     implements NavigableSet<E>, SortedIterable<E> {
@@ -72,7 +72,6 @@ public abstract class ImmutableSortedSet<E> extends ImmutableSet<E>
    *
    * @since 33.2.0 (available since 21.0 in guava-jre)
    */
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // Users will use this only if they're already using streams.
   public static <E> Collector<E, ?, ImmutableSortedSet<E>> toImmutableSortedSet(
       Comparator<? super E> comparator) {
@@ -776,11 +775,11 @@ public abstract class ImmutableSortedSet<E> extends ImmutableSet<E>
    * implementation type is an implementation detail.
    */
   @J2ktIncompatible // serialization
-  private static class SerializedForm<E> implements Serializable {
+  private static final class SerializedForm<E> implements Serializable {
     final Comparator<? super E> comparator;
     final Object[] elements;
 
-    public SerializedForm(Comparator<? super E> comparator, Object[] elements) {
+    SerializedForm(Comparator<? super E> comparator, Object[] elements) {
       this.comparator = comparator;
       this.elements = elements;
     }
@@ -814,7 +813,6 @@ public abstract class ImmutableSortedSet<E> extends ImmutableSet<E>
    */
   @DoNotCall("Use toImmutableSortedSet")
   @Deprecated
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // Users will use this only if they're already using streams.
   public static <E> Collector<E, ?, ImmutableSet<E>> toImmutableSet() {
     throw new UnsupportedOperationException();
