@@ -35,7 +35,6 @@ import org.jspecify.annotations.Nullable;
  * @since 33.2.0 (available since 21.0 in guava-jre)
  */
 @GwtCompatible
-@SuppressWarnings("Java7ApiChecker")
 @IgnoreJRERequirement // Users will use this only if they're already using streams.
 public final class MoreCollectors {
 
@@ -91,6 +90,7 @@ public final class MoreCollectors {
    * This atrocity is here to let us report several of the elements in the stream if there were more
    * than one, not just two.
    */
+  @SuppressWarnings("EmptyList") // ImmutableList doesn't support nullable element types
   private static final class ToOptionalState {
     static final int MAX_EXTRAS = 4;
 
