@@ -34,7 +34,7 @@ import org.jspecify.annotations.Nullable;
  * @author Kevin Bourrillion
  * @since 2.0
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @SuppressWarnings("AvoidObjectArrays")
 public final class ObjectArrays {
 
