@@ -123,8 +123,7 @@ import org.jspecify.annotations.Nullable;
 @GwtCompatible
 @SuppressWarnings("rawtypes") // https://github.com/google/guava/issues/989
 @Immutable(containerOf = "C")
-public final class Range<C extends Comparable> extends RangeGwtSerializationDependencies
-    implements Predicate<C>, Serializable {
+public final class Range<C extends Comparable> implements Predicate<C>, Serializable {
   @SuppressWarnings("unchecked")
   static <C extends Comparable<?>> Ordering<Range<C>> rangeLexOrdering() {
     return (Ordering<Range<C>>) RangeLexOrdering.INSTANCE;
@@ -704,7 +703,7 @@ public final class Range<C extends Comparable> extends RangeGwtSerializationDepe
   }
 
   /** Needed to serialize sorted collections of Ranges. */
-  private static class RangeLexOrdering extends Ordering<Range<?>> implements Serializable {
+  private static final class RangeLexOrdering extends Ordering<Range<?>> implements Serializable {
     static final Ordering<?> INSTANCE = new RangeLexOrdering();
 
     @Override
