@@ -19,6 +19,8 @@ package com.google.common.collect;
 import static com.google.common.base.Preconditions.checkArgument;
 import static com.google.common.base.Preconditions.checkNotNull;
 import static com.google.common.collect.CollectPreconditions.checkNonnegative;
+import static com.google.common.math.IntMath.saturatedAdd;
+import static java.lang.Math.max;
 import static java.lang.Math.min;
 import static java.util.Arrays.asList;
 
@@ -69,7 +71,7 @@ import org.jspecify.annotations.Nullable;
  * @author Chris Povirk
  * @since 2.0
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 public final class Sets {
   private Sets() {}
 
@@ -100,7 +102,6 @@ public final class Sets {
    * @param otherElements the rest of the elements the set should contain
    * @return an immutable set containing those elements, minus duplicates
    */
-  @GwtCompatible(serializable = true)
   public static <E extends Enum<E>> ImmutableSet<E> immutableEnumSet(
       E anElement, E... otherElements) {
     return ImmutableEnumSet.asImmutable(EnumSet.of(anElement, otherElements));
@@ -116,7 +117,6 @@ public final class Sets {
    * @param elements the elements, all of the same {@code enum} type, that the set should contain
    * @return an immutable set containing those elements, minus duplicates
    */
-  @GwtCompatible(serializable = true)
   public static <E extends Enum<E>> ImmutableSet<E> immutableEnumSet(Iterable<E> elements) {
     if (elements instanceof ImmutableEnumSet) {
       return (ImmutableEnumSet<E>) elements;
@@ -146,7 +146,6 @@ public final class Sets {
    *
    * @since 33.2.0 (available since 21.0 in guava-jre)
    */
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // Users will use this only if they're already using streams.
   public static <E extends Enum<E>> Collector<E, ?, ImmutableSet<E>> toImmutableEnumSet() {
     return CollectCollectors.toImmutableEnumSet();
@@ -244,7 +243,7 @@ public final class Sets {
    */
   @SuppressWarnings("NonApiType") // acts as a direct substitute for a constructor call
   public static <E extends @Nullable Object> HashSet<E> newHashSet(Iterator<? extends E> elements) {
-    HashSet<E> set = newHashSet();
+    HashSet<E> set = new HashSet<>();
     Iterators.addAll(set, elements);
     return set;
   }
@@ -341,7 +340,7 @@ public final class Sets {
     if (elements instanceof Collection) {
       return new LinkedHashSet<>((Collection<? extends E>) elements);
     }
-    LinkedHashSet<E> set = newLinkedHashSet();
+    LinkedHashSet<E> set = new LinkedHashSet<>();
     Iterables.addAll(set, elements);
     return set;
   }
@@ -602,12 +601,11 @@ public final class Sets {
      */
     public ImmutableSet<@NonNull E> immutableCopy() {
       // Not using ImmutableSet.copyOf() to avoid iterating thrice (isEmpty, size, iterator).
-      int upperBoundSize = upperBoundSize();
-      if (upperBoundSize == 0) {
+      int maxSize = maxSize();
+      if (maxSize == 0) {
         return ImmutableSet.of();
       }
-      ImmutableSet.Builder<@NonNull E> builder =
-          ImmutableSet.builderWithExpectedSize(upperBoundSize);
+      ImmutableSet.Builder<@NonNull E> builder = ImmutableSet.builderWithExpectedSize(maxSize);
       for (E element : this) {
         builder.add(checkNotNull(element));
       }
@@ -720,16 +718,88 @@ public final class Sets {
     @Override
     public abstract UnmodifiableIterator<E> iterator();
 
-    /**
-     * Returns the upper bound on the size of this set view.
-     *
-     * <p>This method is used to presize the underlying collection when converting to an {@link
-     * ImmutableSet}.
-     */
-    abstract int upperBoundSize();
+    @Override
+    @SuppressWarnings("EqualsHashCode") // same semantics
+    public boolean equals(@Nullable Object object) {
+      if (object == this) {
+        return true;
+      }
+      if (!(object instanceof Set)) {
+        return false;
+      }
+      Set<?> that = (Set<?>) object;
 
-    static int upperBoundSize(Set<?> set) {
-      return set instanceof SetView ? ((SetView) set).upperBoundSize() : set.size();
+      int thatMaxSize = maxSize(that);
+      if (minSize() > thatMaxSize) {
+        return false; // this.size() > that.size()
+      }
+      int thatMinSize = minSize(that);
+      if (maxSize() < thatMinSize) {
+        return false; // this.size() < that.size()
+      }
+
+      // the base implementation from AbstractSet uses size() and containsAll()
+      // both require iterating over the entire SetView
+      // we avoid iterating twice by doing the equivalent of both in one iteration
+      int thisSize = 0;
+      for (E e : this) {
+        try {
+          if (!that.contains(e)) {
+            return false;
+          }
+        } catch (NullPointerException | ClassCastException ignored) {
+          return false;
+        }
+        thisSize++;
+      } // that.containsAll(this) so that.size() >= this.size()
+
+      if (thisSize == thatMaxSize) {
+        // this.size() == maxSize(that) >= that.size() >= this.size()
+        return true; // this.size() == that.size()
+      } else if (thisSize < thatMinSize) {
+        // this.size() < minSize(that) <= that.size()
+        return false; // this.size() < that.size()
+      } else { // that can only be a SetView at this point
+        int thatSize = 0;
+        for (Object unused : that) {
+          if (++thatSize > thisSize) {
+            return false;
+          }
+        }
+        return true; // that.size() == this.size()
+      }
+    }
+
+    /**
+     * Returns a lower bound for {@link #size()} based on the sizes of the backing sets.
+     *
+     * <p>This is more efficient than {@link #size()}, which iterates over the entire {@link
+     * SetView}.
+     */
+    abstract int minSize();
+
+    /**
+     * Returns the {@link #minSize()} of {@code set} if it is a {@link SetView}, or the exact {@link
+     * #size()} of {@code set} otherwise.
+     */
+    static int minSize(Set<?> set) {
+      return set instanceof SetView ? ((SetView<?>) set).minSize() : set.size();
+    }
+
+    /**
+     * Returns an upper bound for {@link #size()} based on the sizes of the backing sets.
+     *
+     * <p>This is more efficient than {@link #size()}, which iterates over the entire {@link
+     * SetView}.
+     */
+    abstract int maxSize();
+
+    /**
+     * Returns the {@link #maxSize()} of {@code set} if it is a {@link SetView}, or the exact {@link
+     * #size()} of {@code set} otherwise.
+     */
+    static int maxSize(Set<?> set) {
+      return set instanceof SetView ? ((SetView<?>) set).maxSize() : set.size();
     }
   }
 
@@ -800,8 +870,13 @@ public final class Sets {
       }
 
       @Override
-      int upperBoundSize() {
-        return upperBoundSize(set1) + upperBoundSize(set2);
+      int minSize() {
+        return max(minSize(set1), minSize(set2));
+      }
+
+      @Override
+      int maxSize() {
+        return saturatedAdd(maxSize(set1), maxSize(set2));
       }
     };
   }
@@ -883,8 +958,13 @@ public final class Sets {
       }
 
       @Override
-      int upperBoundSize() {
-        return min(upperBoundSize(set1), upperBoundSize(set2));
+      int minSize() {
+        return 0;
+      }
+
+      @Override
+      int maxSize() {
+        return min(maxSize(set1), maxSize(set2));
       }
     };
   }
@@ -944,8 +1024,13 @@ public final class Sets {
       }
 
       @Override
-      int upperBoundSize() {
-        return upperBoundSize(set1);
+      int minSize() {
+        return max(minSize(set1) - maxSize(set2), 0);
+      }
+
+      @Override
+      int maxSize() {
+        return maxSize(set1);
       }
     };
   }
@@ -1018,8 +1103,14 @@ public final class Sets {
       }
 
       @Override
-      int upperBoundSize() {
-        return upperBoundSize(set1) + upperBoundSize(set2);
+      int minSize() {
+        int difference = minSize(set1) - maxSize(set2);
+        return difference >= 0 ? difference : max(minSize(set2) - maxSize(set1), 0);
+      }
+
+      @Override
+      int maxSize() {
+        return saturatedAdd(maxSize(set1), maxSize(set2));
       }
     };
   }
@@ -1208,8 +1299,8 @@ public final class Sets {
   }
 
   @GwtIncompatible // NavigableSet
-  private static class FilteredNavigableSet<E extends @Nullable Object> extends FilteredSortedSet<E>
-      implements NavigableSet<E> {
+  private static final class FilteredNavigableSet<E extends @Nullable Object>
+      extends FilteredSortedSet<E> implements NavigableSet<E> {
     FilteredNavigableSet(NavigableSet<E> unfiltered, Predicate<? super E> predicate) {
       super(unfiltered, predicate);
     }
@@ -1535,7 +1626,6 @@ public final class Sets {
    * @see <a href="http://en.wikipedia.org/wiki/Power_set">Power set article at Wikipedia</a>
    * @since 4.0
    */
-  @GwtCompatible(serializable = false)
   public static <E> Set<Set<E>> powerSet(Set<E> set) {
     return new PowerSet<E>(set);
   }
