@@ -56,7 +56,7 @@ import org.jspecify.annotations.Nullable;
  * @author Jared Levy
  * @since 2.0
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 public final class TreeMultiset<E extends @Nullable Object> extends AbstractSortedMultiset<E>
     implements Serializable {
 
@@ -551,11 +551,11 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
   private static final class Reference<T> {
     private @Nullable T value;
 
-    public @Nullable T get() {
+    @Nullable T get() {
       return value;
     }
 
-    public void checkAndSet(@Nullable T expected, @Nullable T newValue) {
+    void checkAndSet(@Nullable T expected, @Nullable T newValue) {
       if (value != expected) {
         throw new ConcurrentModificationException();
       }
@@ -1053,9 +1053,9 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
    * @serialData the comparator, the number of distinct elements, the first element, its count, the
    *     second element, its count, and so on
    */
+  @GwtIncompatible
   @J2ktIncompatible
-  @GwtIncompatible // java.io.ObjectOutputStream
-  private void writeObject(ObjectOutputStream stream) throws IOException {
+    private void writeObject(ObjectOutputStream stream) throws IOException {
     stream.defaultWriteObject();
     stream.writeObject(elementSet().comparator());
     Serialization.writeMultiset(this, stream);
