@@ -21,7 +21,6 @@ import static com.google.common.graph.GraphConstants.NODE_NOT_IN_GRAPH;
 import static java.util.Objects.requireNonNull;
 
 import com.google.common.annotations.Beta;
-import com.google.common.base.Objects;
 import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.Iterables;
 import com.google.common.collect.Iterators;
@@ -33,6 +32,7 @@ import java.util.Deque;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Queue;
 import java.util.Set;
 import org.jspecify.annotations.Nullable;
@@ -165,7 +165,7 @@ public final class Graphs extends GraphsBridgeMethods {
    */
   private static boolean canTraverseWithoutReusingEdge(
       Graph<?> graph, Object nextNode, @Nullable Object previousNode) {
-    if (graph.isDirected() || !Objects.equal(previousNode, nextNode)) {
+    if (graph.isDirected() || !Objects.equals(previousNode, nextNode)) {
       return true;
     }
     // This falls into the undirected A->B->A case. The Graph interface does not support parallel
@@ -220,13 +220,19 @@ public final class Graphs extends GraphsBridgeMethods {
   }
 
   /**
-   * Returns the set of nodes that are reachable from {@code node}. Node B is defined as reachable
-   * from node A if there exists a path (a sequence of adjacent outgoing edges) starting at node A
-   * and ending at node B. Note that a node is always reachable from itself via a zero-length path.
+   * Returns the set of nodes that are reachable from {@code node}. Specifically, it returns all
+   * nodes {@code v} such that there exists a path (a sequence of adjacent outgoing edges) starting
+   * at {@code node} and ending at {@code v}. This implementation includes {@code node} as the first
+   * element in the result.
    *
-   * <p>This is a "snapshot" based on the current topology of {@code graph}, rather than a live view
-   * of the set of nodes reachable from {@code node}. In other words, the returned {@link Set} will
-   * not be updated after modifications to {@code graph}.
+   * <p>If needed, the {@link Traverser} class provides more flexible and lighter-weight ways to
+   * list the nodes reachable from a given node or nodes. See the <a
+   * href="https://github.com/google/guava/wiki/GraphsExplained#Graph-traversal">"Graph traversal"
+   * section of the Guava User's Guide</a> for more information.
+   *
+   * <p>The {@link Set} returned is a "snapshot" based on the current topology of {@code graph},
+   * rather than a live view. In other words, modifications to {@code graph} made after this method
+   * returns will not be reflected in the set.
    *
    * @throws IllegalArgumentException if {@code node} is not present in {@code graph}
    * @since 33.1.0 (present with return type {@code Set} since 20.0)
@@ -297,7 +303,7 @@ public final class Graphs extends GraphsBridgeMethods {
 
   // NOTE: this should work as long as the delegate graph's implementation of edges() (like that of
   // AbstractGraph) derives its behavior from calling successors().
-  private static class TransposedGraph<N> extends ForwardingGraph<N> {
+  private static final class TransposedGraph<N> extends ForwardingGraph<N> {
     private final Graph<N> graph;
 
     TransposedGraph(Graph<N> graph) {
@@ -354,7 +360,7 @@ public final class Graphs extends GraphsBridgeMethods {
 
   // NOTE: this should work as long as the delegate graph's implementation of edges() (like that of
   // AbstractValueGraph) derives its behavior from calling successors().
-  private static class TransposedValueGraph<N, V> extends ForwardingValueGraph<N, V> {
+  private static final class TransposedValueGraph<N, V> extends ForwardingValueGraph<N, V> {
     private final ValueGraph<N, V> graph;
 
     TransposedValueGraph(ValueGraph<N, V> graph) {
@@ -407,7 +413,7 @@ public final class Graphs extends GraphsBridgeMethods {
     }
   }
 
-  private static class TransposedNetwork<N, E> extends ForwardingNetwork<N, E> {
+  private static final class TransposedNetwork<N, E> extends ForwardingNetwork<N, E> {
     private final Network<N, E> network;
 
     TransposedNetwork(Network<N, E> network) {
