@@ -24,7 +24,6 @@ import com.google.common.base.Optional;
 import com.google.common.base.Splitter;
 import com.google.common.collect.AbstractIterator;
 import com.google.common.collect.ImmutableList;
-import com.google.common.collect.Lists;
 import com.google.errorprone.annotations.CanIgnoreReturnValue;
 import com.google.errorprone.annotations.MustBeClosed;
 import java.io.BufferedReader;
@@ -36,6 +35,7 @@ import java.io.StringReader;
 import java.io.UncheckedIOException;
 import java.io.Writer;
 import java.nio.charset.Charset;
+import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 import java.util.function.Consumer;
@@ -155,7 +155,6 @@ public abstract class CharSource {
    * @since 33.4.0 (but since 22.0 in the JRE flavor)
    */
   @MustBeClosed
-  @SuppressWarnings("Java7ApiChecker")
   // If users use this when they shouldn't, we hope that NewApi will catch subsequent Stream calls.
   @IgnoreJRERequirement
   public Stream<String> lines() throws IOException {
@@ -163,7 +162,6 @@ public abstract class CharSource {
     return reader.lines().onClose(() -> closeUnchecked(reader));
   }
 
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // helper for lines()
   /*
    * If we make these calls inline inside the lambda inside lines(), we get an Animal Sniffer error,
@@ -231,7 +229,7 @@ public abstract class CharSource {
     }
   }
 
-  private long countBySkipping(Reader reader) throws IOException {
+  private static long countBySkipping(Reader reader) throws IOException {
     long count = 0;
     long read;
     while ((read = reader.skip(Long.MAX_VALUE)) != 0) {
@@ -340,7 +338,7 @@ public abstract class CharSource {
     Closer closer = Closer.create();
     try {
       BufferedReader reader = closer.register(openBufferedStream());
-      List<String> result = Lists.newArrayList();
+      List<String> result = new ArrayList<>();
       String line;
       while ((line = reader.readLine()) != null) {
         result.add(line);
@@ -396,7 +394,6 @@ public abstract class CharSource {
    *     throws an {@code UncheckedIOException}
    * @since 33.4.0 (but since 22.0 in the JRE flavor)
    */
-  @SuppressWarnings("Java7ApiChecker")
   /*
    * We have to rely on users not to call this without library desugaring, as NewApi won't flag
    * Consumer creation.
@@ -546,9 +543,9 @@ public abstract class CharSource {
 
     private static final Splitter LINE_SPLITTER = Splitter.onPattern("\r\n|\n|\r");
 
-    protected final CharSequence seq;
+    final CharSequence seq;
 
-    protected CharSequenceCharSource(CharSequence seq) {
+    CharSequenceCharSource(CharSequence seq) {
       this.seq = checkNotNull(seq);
     }
 
@@ -583,7 +580,7 @@ public abstract class CharSource {
      */
     private Iterator<String> linesIterator() {
       return new AbstractIterator<String>() {
-        Iterator<String> lines = LINE_SPLITTER.split(seq).iterator();
+        final Iterator<String> lines = LINE_SPLITTER.split(seq).iterator();
 
         @Override
         protected @Nullable String computeNext() {
@@ -600,7 +597,6 @@ public abstract class CharSource {
     }
 
     @Override
-    @SuppressWarnings("Java7ApiChecker")
     // If users use this when they shouldn't, we hope that NewApi will catch subsequent Stream calls
     @IgnoreJRERequirement
     public Stream<String> lines() {
@@ -652,7 +648,7 @@ public abstract class CharSource {
    * </ul>
    */
   private static class StringCharSource extends CharSequenceCharSource {
-    protected StringCharSource(String seq) {
+    StringCharSource(String seq) {
       super(seq);
     }
 
