@@ -19,8 +19,6 @@ import static com.google.common.base.Preconditions.checkElementIndex;
 import static com.google.common.base.Preconditions.checkNotNull;
 import static com.google.common.base.Preconditions.checkPositionIndexes;
 import static com.google.common.base.Strings.lenientFormat;
-import static java.lang.Double.NEGATIVE_INFINITY;
-import static java.lang.Double.POSITIVE_INFINITY;
 
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.annotations.GwtIncompatible;
@@ -49,33 +47,30 @@ import org.jspecify.annotations.Nullable;
  * @author Kevin Bourrillion
  * @since 1.0
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 public final class Doubles extends DoublesMethodsForWeb {
   private Doubles() {}
 
   /**
    * The number of bytes required to represent a primitive {@code double} value.
    *
-   * <p><b>Java 8+ users:</b> use {@link Double#BYTES} instead.
+   * <p>Prefer {@link Double#BYTES} instead.
    *
    * @since 10.0
    */
-  public static final int BYTES = Double.SIZE / Byte.SIZE;
+  // The constants value gets inlined here.
+  @SuppressWarnings("AndroidJdkLibsChecker")
+  public static final int BYTES = Double.BYTES;
 
   /**
-   * Returns a hash code for {@code value}; equal to the result of invoking {@code ((Double)
-   * value).hashCode()}.
-   *
-   * <p><b>Java 8+ users:</b> use {@link Double#hashCode(double)} instead.
+   * Returns a hash code for {@code value}; obsolete alternative to {@link Double#hashCode(double)}.
    *
    * @param value a primitive {@code double} value
    * @return a hash code for the value
    */
+  @InlineMe(replacement = "Double.hashCode(value)")
   public static int hashCode(double value) {
-    return ((Double) value).hashCode();
-    // TODO(kevinb): do it this way when we can (GWT problem):
-    // long bits = Double.doubleToLongBits(value);
-    // return (int) (bits ^ (bits >>> 32));
+    return Double.hashCode(value);
   }
 
   /**
@@ -101,12 +96,13 @@ public final class Doubles extends DoublesMethodsForWeb {
    * Returns {@code true} if {@code value} represents a real number. This is equivalent to, but not
    * necessarily implemented as, {@code !(Double.isInfinite(value) || Double.isNaN(value))}.
    *
-   * <p><b>Java 8+ users:</b> use {@link Double#isFinite(double)} instead.
+   * <p>Prefer {@link Double#isFinite(double)} instead.
    *
    * @since 10.0
    */
+  @InlineMe(replacement = "Double.isFinite(value)")
   public static boolean isFinite(double value) {
-    return NEGATIVE_INFINITY < value && value < POSITIVE_INFINITY;
+    return Double.isFinite(value);
   }
 
   /**
@@ -585,8 +581,7 @@ public final class Doubles extends DoublesMethodsForWeb {
     return new DoubleArrayAsList(backingArray);
   }
 
-  @GwtCompatible
-  private static class DoubleArrayAsList extends AbstractList<Double>
+  private static final class DoubleArrayAsList extends AbstractList<Double>
       implements RandomAccess, Serializable {
     final double[] array;
     final int start;
@@ -619,7 +614,6 @@ public final class Doubles extends DoublesMethodsForWeb {
     }
 
     @Override
-    @SuppressWarnings("Java7ApiChecker")
     /*
      * This is an override that is not directly visible to callers, so NewApi will catch calls to
      * Collection.spliterator() where necessary.
@@ -704,7 +698,7 @@ public final class Doubles extends DoublesMethodsForWeb {
     public int hashCode() {
       int result = 1;
       for (int i = start; i < end; i++) {
-        result = 31 * result + Doubles.hashCode(array[i]);
+        result = 31 * result + Double.hashCode(array[i]);
       }
       return result;
     }
