@@ -173,7 +173,6 @@ public final class ImmutableDoubleArray implements Serializable {
    *
    * @since 33.4.0 (but since 22.0 in the JRE flavor)
    */
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // Users will use this only if they're already using streams.
   public static ImmutableDoubleArray copyOf(DoubleStream stream) {
     // Note this uses very different growth behavior from copyOf(Iterable) and the builder.
@@ -278,7 +277,6 @@ public final class ImmutableDoubleArray implements Serializable {
      *
      * @since 33.4.0 (but since 22.0 in the JRE flavor)
      */
-    @SuppressWarnings("Java7ApiChecker")
     @IgnoreJRERequirement // Users will use this only if they're already using streams.
     @CanIgnoreReturnValue
     public Builder addAll(DoubleStream stream) {
@@ -427,7 +425,6 @@ public final class ImmutableDoubleArray implements Serializable {
    *
    * @since 33.4.0 (but since 22.0 in the JRE flavor)
    */
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // We rely on users not to call this without library desugaring.
   public void forEach(DoubleConsumer consumer) {
     checkNotNull(consumer);
@@ -441,7 +438,6 @@ public final class ImmutableDoubleArray implements Serializable {
    *
    * @since 33.4.0 (but since 22.0 in the JRE flavor)
    */
-  @SuppressWarnings("Java7ApiChecker")
   // If users use this when they shouldn't, we hope that NewApi will catch subsequent stream calls
   @IgnoreJRERequirement
   public DoubleStream stream() {
@@ -467,7 +463,6 @@ public final class ImmutableDoubleArray implements Serializable {
         : new ImmutableDoubleArray(array, start + startIndex, start + endIndex);
   }
 
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // used only from APIs that use streams
   /*
    * We declare this as package-private, rather than private, to avoid generating a synthetic
@@ -493,7 +488,8 @@ public final class ImmutableDoubleArray implements Serializable {
     return new AsList(this);
   }
 
-  static class AsList extends AbstractList<Double> implements RandomAccess, Serializable {
+  private static final class AsList extends AbstractList<Double>
+      implements RandomAccess, Serializable {
     private final ImmutableDoubleArray parent;
 
     private AsList(ImmutableDoubleArray parent) {
@@ -534,7 +530,6 @@ public final class ImmutableDoubleArray implements Serializable {
 
     // The default List spliterator is not efficiently splittable
     @Override
-    @SuppressWarnings("Java7ApiChecker")
     /*
      * This is an override that is not directly visible to callers, so NewApi will catch calls to
      * Collection.spliterator() where necessary.
@@ -615,7 +610,7 @@ public final class ImmutableDoubleArray implements Serializable {
     int hash = 1;
     for (int i = start; i < end; i++) {
       hash *= 31;
-      hash += Doubles.hashCode(array[i]);
+      hash += Double.hashCode(array[i]);
     }
     return hash;
   }
