@@ -172,7 +172,6 @@ public final class ImmutableLongArray implements Serializable {
    *
    * @since 33.4.0 (but since 22.0 in the JRE flavor)
    */
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // Users will use this only if they're already using streams.
   public static ImmutableLongArray copyOf(LongStream stream) {
     // Note this uses very different growth behavior from copyOf(Iterable) and the builder.
@@ -277,7 +276,6 @@ public final class ImmutableLongArray implements Serializable {
      *
      * @since 33.4.0 (but since 22.0 in the JRE flavor)
      */
-    @SuppressWarnings("Java7ApiChecker")
     @IgnoreJRERequirement // Users will use this only if they're already using streams.
     @CanIgnoreReturnValue
     public Builder addAll(LongStream stream) {
@@ -424,7 +422,6 @@ public final class ImmutableLongArray implements Serializable {
    *
    * @since 33.4.0 (but since 22.0 in the JRE flavor)
    */
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // We rely on users not to call this without library desugaring.
   public void forEach(LongConsumer consumer) {
     checkNotNull(consumer);
@@ -438,7 +435,6 @@ public final class ImmutableLongArray implements Serializable {
    *
    * @since 33.4.0 (but since 22.0 in the JRE flavor)
    */
-  @SuppressWarnings("Java7ApiChecker")
   // If users use this when they shouldn't, we hope that NewApi will catch subsequent stream calls
   @IgnoreJRERequirement
   public LongStream stream() {
@@ -464,7 +460,6 @@ public final class ImmutableLongArray implements Serializable {
         : new ImmutableLongArray(array, start + startIndex, start + endIndex);
   }
 
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // used only from APIs that use streams
   /*
    * We declare this as package-private, rather than private, to avoid generating a synthetic
@@ -490,7 +485,8 @@ public final class ImmutableLongArray implements Serializable {
     return new AsList(this);
   }
 
-  static class AsList extends AbstractList<Long> implements RandomAccess, Serializable {
+  private static final class AsList extends AbstractList<Long>
+      implements RandomAccess, Serializable {
     private final ImmutableLongArray parent;
 
     private AsList(ImmutableLongArray parent) {
@@ -531,7 +527,6 @@ public final class ImmutableLongArray implements Serializable {
 
     // The default List spliterator is not efficiently splittable
     @Override
-    @SuppressWarnings("Java7ApiChecker")
     /*
      * This is an override that is not directly visible to callers, so NewApi will catch calls to
      * Collection.spliterator() where necessary.
@@ -607,7 +602,7 @@ public final class ImmutableLongArray implements Serializable {
     int hash = 1;
     for (int i = start; i < end; i++) {
       hash *= 31;
-      hash += Longs.hashCode(array[i]);
+      hash += Long.hashCode(array[i]);
     }
     return hash;
   }
