@@ -24,6 +24,7 @@ import com.google.common.annotations.GwtIncompatible;
 import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.base.Converter;
 import com.google.errorprone.annotations.InlineMe;
+import com.google.errorprone.annotations.InlineMeValidationDisabled;
 import java.io.Serializable;
 import java.util.AbstractList;
 import java.util.Arrays;
@@ -46,16 +47,18 @@ import org.jspecify.annotations.Nullable;
  * @author Kevin Bourrillion
  * @since 1.0
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 public final class Ints extends IntsMethodsForWeb {
   private Ints() {}
 
   /**
    * The number of bytes required to represent a primitive {@code int} value.
    *
-   * <p><b>Java 8+ users:</b> use {@link Integer#BYTES} instead.
+   * <p>Prefer {@link Integer#BYTES} instead.
    */
-  public static final int BYTES = Integer.SIZE / Byte.SIZE;
+  // The constants value gets inlined here.
+  @SuppressWarnings("AndroidJdkLibsChecker")
+  public static final int BYTES = Integer.BYTES;
 
   /**
    * The largest power of two that can be represented as an {@code int}.
@@ -65,14 +68,14 @@ public final class Ints extends IntsMethodsForWeb {
   public static final int MAX_POWER_OF_TWO = 1 << (Integer.SIZE - 2);
 
   /**
-   * Returns a hash code for {@code value}; equal to the result of invoking {@code ((Integer)
-   * value).hashCode()}.
-   *
-   * <p><b>Java 8+ users:</b> use {@link Integer#hashCode(int)} instead.
+   * Returns a hash code for {@code value}; obsolete alternative to {@link Integer#hashCode(int)}.
    *
    * @param value a primitive {@code int} value
    * @return a hash code for the value
    */
+  @InlineMe(replacement = "Integer.hashCode(value)")
+  @InlineMeValidationDisabled(
+      "The hash code of a int is the int itself, so it's simplest to return that.")
   public static int hashCode(int value) {
     return value;
   }
@@ -80,6 +83,10 @@ public final class Ints extends IntsMethodsForWeb {
   /**
    * Returns the {@code int} value that is equal to {@code value}, if possible.
    *
+   * <p><b>Note:</b> this method is now unnecessary and should be treated as deprecated. Use {@link
+   * Math#toIntExact(long)} instead, but be aware that that method throws {@link
+   * ArithmeticException} rather than {@link IllegalArgumentException}.
+   *
    * @param value any value in the range of the {@code int} type
    * @return the {@code int} value that equals {@code value}
    * @throws IllegalArgumentException if {@code value} is greater than {@link Integer#MAX_VALUE} or
@@ -656,8 +663,7 @@ public final class Ints extends IntsMethodsForWeb {
     return new IntArrayAsList(backingArray);
   }
 
-  @GwtCompatible
-  private static class IntArrayAsList extends AbstractList<Integer>
+  private static final class IntArrayAsList extends AbstractList<Integer>
       implements RandomAccess, Serializable {
     final int[] array;
     final int start;
@@ -690,7 +696,6 @@ public final class Ints extends IntsMethodsForWeb {
     }
 
     @Override
-    @SuppressWarnings("Java7ApiChecker")
     /*
      * This is an override that is not directly visible to callers, so NewApi will catch calls to
      * Collection.spliterator() where necessary.
@@ -774,7 +779,7 @@ public final class Ints extends IntsMethodsForWeb {
     public int hashCode() {
       int result = 1;
       for (int i = start; i < end; i++) {
-        result = 31 * result + Ints.hashCode(array[i]);
+        result = 31 * result + Integer.hashCode(array[i]);
       }
       return result;
     }
