@@ -53,9 +53,11 @@ public final class Longs {
   /**
    * The number of bytes required to represent a primitive {@code long} value.
    *
-   * <p><b>Java 8+ users:</b> use {@link Long#BYTES} instead.
+   * <p>Prefer {@link Long#BYTES} instead.
    */
-  public static final int BYTES = Long.SIZE / Byte.SIZE;
+  // The constants value gets inlined here.
+  @SuppressWarnings("AndroidJdkLibsChecker")
+  public static final int BYTES = Long.BYTES;
 
   /**
    * The largest power of two that can be represented as a {@code long}.
@@ -65,20 +67,14 @@ public final class Longs {
   public static final long MAX_POWER_OF_TWO = 1L << (Long.SIZE - 2);
 
   /**
-   * Returns a hash code for {@code value}; equal to the result of invoking {@code ((Long)
-   * value).hashCode()}.
-   *
-   * <p>This method always return the value specified by {@link Long#hashCode()} in java, which
-   * might be different from {@code ((Long) value).hashCode()} in GWT because {@link
-   * Long#hashCode()} in GWT does not obey the JRE contract.
-   *
-   * <p><b>Java 8+ users:</b> use {@link Long#hashCode(long)} instead.
+   * Returns a hash code for {@code value}; obsolete alternative to {@link Long#hashCode(long)}.
    *
    * @param value a primitive {@code long} value
    * @return a hash code for the value
    */
+  @InlineMe(replacement = "Long.hashCode(value)")
   public static int hashCode(long value) {
-    return (int) (value ^ (value >>> 32));
+    return Long.hashCode(value);
   }
 
   /**
@@ -719,8 +715,7 @@ public final class Longs {
     return new LongArrayAsList(backingArray);
   }
 
-  @GwtCompatible
-  private static class LongArrayAsList extends AbstractList<Long>
+  private static final class LongArrayAsList extends AbstractList<Long>
       implements RandomAccess, Serializable {
     final long[] array;
     final int start;
@@ -753,7 +748,6 @@ public final class Longs {
     }
 
     @Override
-    @SuppressWarnings("Java7ApiChecker")
     /*
      * This is an override that is not directly visible to callers, so NewApi will catch calls to
      * Collection.spliterator() where necessary.
@@ -837,7 +831,7 @@ public final class Longs {
     public int hashCode() {
       int result = 1;
       for (int i = start; i < end; i++) {
-        result = 31 * result + Longs.hashCode(array[i]);
+        result = 31 * result + Long.hashCode(array[i]);
       }
       return result;
     }
