@@ -17,6 +17,7 @@ package com.google.common.primitives;
 import static com.google.common.base.Preconditions.checkArgument;
 import static com.google.common.base.Preconditions.checkNotNull;
 import static com.google.common.base.Preconditions.checkPositionIndexes;
+import static java.lang.Byte.toUnsignedInt;
 import static java.security.AccessController.doPrivileged;
 import static java.util.Objects.requireNonNull;
 
@@ -24,6 +25,7 @@ import com.google.common.annotations.GwtIncompatible;
 import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.errorprone.annotations.CanIgnoreReturnValue;
+import com.google.errorprone.annotations.InlineMe;
 import java.lang.reflect.Field;
 import java.nio.ByteOrder;
 import java.security.PrivilegedActionException;
@@ -73,12 +75,13 @@ public final class UnsignedBytes {
    * Returns the value of the given byte as an integer, when treated as unsigned. That is, returns
    * {@code value + 256} if {@code value} is negative; {@code value} itself otherwise.
    *
-   * <p><b>Java 8+ users:</b> use {@link Byte#toUnsignedInt(byte)} instead.
+   * <p>Prefer {@link Byte#toUnsignedInt(byte)} instead.
    *
    * @since 6.0
    */
+  @InlineMe(replacement = "Byte.toUnsignedInt(value)")
   public static int toInt(byte value) {
-    return value & UNSIGNED_MASK;
+    return Byte.toUnsignedInt(value);
   }
 
   /**
@@ -104,7 +107,7 @@ public final class UnsignedBytes {
    *     {@code value} cast to {@code byte} otherwise
    */
   public static byte saturatedCast(long value) {
-    if (value > toInt(MAX_VALUE)) {
+    if (value > toUnsignedInt(MAX_VALUE)) {
       return MAX_VALUE; // -1
     }
     if (value < 0) {
@@ -124,7 +127,7 @@ public final class UnsignedBytes {
    *     greater than {@code b}; or zero if they are equal
    */
   public static int compare(byte a, byte b) {
-    return toInt(a) - toInt(b);
+    return toUnsignedInt(a) - toUnsignedInt(b);
   }
 
   /**
@@ -137,9 +140,9 @@ public final class UnsignedBytes {
    */
   public static byte min(byte... array) {
     checkArgument(array.length > 0);
-    int min = toInt(array[0]);
+    int min = toUnsignedInt(array[0]);
     for (int i = 1; i < array.length; i++) {
-      int next = toInt(array[i]);
+      int next = toUnsignedInt(array[i]);
       if (next < min) {
         min = next;
       }
@@ -157,9 +160,9 @@ public final class UnsignedBytes {
    */
   public static byte max(byte... array) {
     checkArgument(array.length > 0);
-    int max = toInt(array[0]);
+    int max = toUnsignedInt(array[0]);
     for (int i = 1; i < array.length; i++) {
-      int next = toInt(array[i]);
+      int next = toUnsignedInt(array[i]);
       if (next > max) {
         max = next;
       }
@@ -192,7 +195,7 @@ public final class UnsignedBytes {
         "radix (%s) must be between Character.MIN_RADIX and Character.MAX_RADIX",
         radix);
     // Benchmarks indicate this is probably not worth optimizing.
-    return Integer.toString(toInt(x), radix);
+    return Integer.toString(toUnsignedInt(x), radix);
   }
 
   /**
@@ -249,7 +252,7 @@ public final class UnsignedBytes {
 
     // For pre-sizing a builder, just get the right order of magnitude
     StringBuilder builder = new StringBuilder(array.length * (3 + separator.length()));
-    builder.append(toInt(array[0]));
+    builder.append(toUnsignedInt(array[0]));
     for (int i = 1; i < array.length; i++) {
       builder.append(separator).append(toString(array[i]));
     }
@@ -290,7 +293,7 @@ public final class UnsignedBytes {
    * available.
    */
   @VisibleForTesting
-  static class LexicographicalComparatorHolder {
+  static final class LexicographicalComparatorHolder {
     static final String UNSAFE_COMPARATOR_NAME =
         LexicographicalComparatorHolder.class.getName() + "$UnsafeComparator";
 
@@ -367,8 +370,6 @@ public final class UnsignedBytes {
       }
 
       @Override
-      // Long.compareUnsigned is available under Android, which is what we really care about.
-      @SuppressWarnings("Java7ApiChecker")
       public int compare(byte[] left, byte[] right) {
         int stride = 8;
         int minLength = Math.min(left.length, right.length);
@@ -455,6 +456,8 @@ public final class UnsignedBytes {
         return lexicographicalComparatorJavaImpl();
       }
     }
+
+    private LexicographicalComparatorHolder() {}
   }
 
   private static byte flip(byte b) {
