@@ -126,7 +126,6 @@ public abstract class AbstractScheduledService implements Service {
      *     next
      * @since 33.4.0 (but since 28.0 in the JRE flavor)
      */
-    @SuppressWarnings("Java7ApiChecker")
     @IgnoreJRERequirement // Users will use this only if they're already using Duration
     public static Scheduler newFixedDelaySchedule(Duration initialDelay, Duration delay) {
       return newFixedDelaySchedule(
@@ -164,7 +163,6 @@ public abstract class AbstractScheduledService implements Service {
      * @param period the period between successive executions of the task
      * @since 33.4.0 (but since 28.0 in the JRE flavor)
      */
-    @SuppressWarnings("Java7ApiChecker")
     @IgnoreJRERequirement // Users will use this only if they're already using Duration
     public static Scheduler newFixedRateSchedule(Duration initialDelay, Duration period) {
       return newFixedRateSchedule(
@@ -218,7 +216,7 @@ public abstract class AbstractScheduledService implements Service {
     private final ReentrantLock lock = new ReentrantLock();
 
     @WeakOuter
-    class Task implements Runnable {
+    final class Task implements Runnable {
       @Override
       public void run() {
         lock.lock();
@@ -368,7 +366,7 @@ public abstract class AbstractScheduledService implements Service {
    */
   protected ScheduledExecutorService executor() {
     @WeakOuter
-    class ThreadFactoryImpl implements ThreadFactory {
+    final class ThreadFactoryImpl implements ThreadFactory {
       @Override
       public Thread newThread(Runnable runnable) {
         return MoreExecutors.newThread(serviceName(), runnable);
@@ -593,7 +591,7 @@ public abstract class AbstractScheduledService implements Service {
        * #cancellationDelegate}.
        */
       @CanIgnoreReturnValue
-      public Cancellable reschedule() {
+      Cancellable reschedule() {
         // invoke the callback outside the lock, prevents some shenanigans.
         Schedule schedule;
         try {
@@ -736,7 +734,6 @@ public abstract class AbstractScheduledService implements Service {
        * @param delay the time from now to delay execution
        * @since 33.4.0 (but since 31.1 in the JRE flavor)
        */
-      @SuppressWarnings("Java7ApiChecker")
       @IgnoreJRERequirement // Users will use this only if they're already using Duration
       public Schedule(Duration delay) {
         this(toNanosSaturated(delay), NANOSECONDS);
