@@ -74,7 +74,7 @@ import org.jspecify.annotations.Nullable;
  * @since 23.0
  */
 @DoNotMock("Use FluentFuture.from(Futures.immediate*Future) or SettableFuture")
-@GwtCompatible(emulated = true)
+@GwtCompatible
 public abstract class FluentFuture<V extends @Nullable Object>
     extends GwtFluentFutureCatchingSpecialization<V> {
 
@@ -271,7 +271,6 @@ public abstract class FluentFuture<V extends @Nullable Object>
    */
   @J2ktIncompatible
   @GwtIncompatible // ScheduledExecutorService
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // Users will use this only if they're already using Duration.
   public final FluentFuture<V> withTimeout(
       Duration timeout, ScheduledExecutorService scheduledExecutor) {
