@@ -56,6 +56,7 @@ import com.google.j2objc.annotations.J2ObjCIncompatible;
 import com.google.j2objc.annotations.WeakOuter;
 import java.lang.ref.WeakReference;
 import java.time.Duration;
+import java.util.ArrayList;
 import java.util.EnumSet;
 import java.util.IdentityHashMap;
 import java.util.List;
@@ -310,7 +311,6 @@ public final class ServiceManager implements ServiceManagerBridge {
    *     become {@linkplain #isHealthy() healthy}.
    * @since 33.4.0 (but since 28.0 in the JRE flavor)
    */
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // Users will use this only if they're already using Duration.
   public void awaitHealthy(Duration timeout) throws TimeoutException {
     awaitHealthy(toNanosSaturated(timeout), TimeUnit.NANOSECONDS);
@@ -364,7 +364,6 @@ public final class ServiceManager implements ServiceManagerBridge {
    * @throws TimeoutException if not all of the services have stopped within the deadline
    * @since 33.4.0 (but since 28.0 in the JRE flavor)
    */
-  @SuppressWarnings("Java7ApiChecker")
   @IgnoreJRERequirement // Users will use this only if they're already using Duration.
   public void awaitStopped(Duration timeout) throws TimeoutException {
     awaitStopped(toNanosSaturated(timeout), TimeUnit.NANOSECONDS);
@@ -432,7 +431,6 @@ public final class ServiceManager implements ServiceManagerBridge {
    * @since 33.4.0 (but since 31.0 in the JRE flavor)
    */
   @J2ObjCIncompatible
-  @SuppressWarnings("Java7ApiChecker")
   // If users use this when they shouldn't, we hope that NewApi will catch subsequent Duration calls
   @IgnoreJRERequirement
   public ImmutableMap<Service, Duration> startupDurations() {
@@ -566,7 +564,7 @@ public final class ServiceManager implements ServiceManagerBridge {
           ready = true;
         } else {
           // This should be an extremely rare race condition.
-          List<Service> servicesInBadStates = Lists.newArrayList();
+          List<Service> servicesInBadStates = new ArrayList<>();
           for (Service service : servicesByState().values()) {
             if (service.state() != NEW) {
               servicesInBadStates.add(service);
