@@ -276,16 +276,7 @@ public abstract class ImmutableMap<K, V> implements Map<K, V>, Serializable {
 
     @CanIgnoreReturnValue
     public Builder<K, V> put(Entry<? extends K, ? extends V> entry) {
-      if (entry instanceof ImmutableEntry) {
-        checkNotNull(entry.getKey());
-        checkNotNull(entry.getValue());
-        @SuppressWarnings("unchecked") // all supported methods are covariant
-        Entry<K, V> immutableEntry = (Entry<K, V>) entry;
-        entries.add(immutableEntry);
-      } else {
-        entries.add(entryOf((K) entry.getKey(), (V) entry.getValue()));
-      }
-      return this;
+      return put(entry.getKey(), entry.getValue());
     }
 
     @CanIgnoreReturnValue
@@ -411,18 +402,22 @@ public abstract class ImmutableMap<K, V> implements Map<K, V>, Serializable {
 
   abstract boolean isPartialView();
 
+  @Override
   public final @Nullable V put(K k, V v) {
     throw new UnsupportedOperationException();
   }
 
+  @Override
   public final @Nullable V remove(Object o) {
     throw new UnsupportedOperationException();
   }
 
+  @Override
   public final void putAll(Map<? extends K, ? extends V> map) {
     throw new UnsupportedOperationException();
   }
 
+  @Override
   public final void clear() {
     throw new UnsupportedOperationException();
   }
@@ -444,6 +439,7 @@ public abstract class ImmutableMap<K, V> implements Map<K, V>, Serializable {
 
   private transient @Nullable ImmutableSet<Entry<K, V>> cachedEntrySet = null;
 
+  @Override
   public final ImmutableSet<Entry<K, V>> entrySet() {
     if (cachedEntrySet != null) {
       return cachedEntrySet;
@@ -455,6 +451,7 @@ public abstract class ImmutableMap<K, V> implements Map<K, V>, Serializable {
 
   private transient @Nullable ImmutableSet<K> cachedKeySet = null;
 
+  @Override
   public ImmutableSet<K> keySet() {
     if (cachedKeySet != null) {
       return cachedKeySet;
@@ -487,6 +484,7 @@ public abstract class ImmutableMap<K, V> implements Map<K, V>, Serializable {
 
   private transient @Nullable ImmutableCollection<V> cachedValues = null;
 
+  @Override
   public ImmutableCollection<V> values() {
     if (cachedValues != null) {
       return cachedValues;
