@@ -26,13 +26,7 @@ import org.jspecify.annotations.Nullable;
  * @author Hayward Chan
  */
 final class SingletonImmutableSet<E> extends ImmutableSet<E> {
-
-  // This reference is used both by the custom field serializer, and by the
-  // GWT compiler to infer the elements of the lists that needs to be
-  // serialized.
-  //
-  // Although this reference is non-final, it doesn't change after set creation.
-  E element;
+  private final E element;
 
   SingletonImmutableSet(E element) {
     this.element = checkNotNull(element);
