@@ -21,8 +21,8 @@ import com.google.common.annotations.GwtCompatible;
 /**
  * @author Chris Povirk
  */
-@GwtCompatible(emulated = true)
-class TestPlatform {
+@GwtCompatible
+final class TestPlatform {
   static boolean intsCanGoOutOfRange() {
     return true;
   }
@@ -30,4 +30,6 @@ class TestPlatform {
   static boolean isAndroid() {
     return false;
   }
+
+  private TestPlatform() {}
 }
