@@ -27,6 +27,7 @@ import com.google.common.testing.ClassSanityTester.FactoryMethodReturnsNullExcep
 import com.google.common.testing.ClassSanityTester.ParameterHasNoDistinctValueException;
 import com.google.common.testing.ClassSanityTester.ParameterNotInstantiableException;
 import com.google.common.testing.NullPointerTester.Visibility;
+import com.google.errorprone.annotations.Keep;
 import java.io.Serializable;
 import java.lang.reflect.InvocationTargetException;
 import java.util.AbstractList;
@@ -113,7 +114,7 @@ public class ClassSanityTesterTest extends TestCase {
 
   private static class BadEqualsFactory {
     /** oneConstantOnly matters now since it can be either null or the constant. */
-    @SuppressWarnings("unused") // Called by reflection
+    @Keep
     public static Object bad(String a, int b, @Nullable OneConstantEnum oneConstantOnly) {
       return new GoodEquals(a, b);
     }
@@ -124,7 +125,7 @@ public class ClassSanityTesterTest extends TestCase {
   }
 
   private static class GoodNullsFactory {
-    @SuppressWarnings("unused") // Called by reflection
+    @Keep
     public static Object good(String s) {
       return new GoodNulls(s);
     }
@@ -157,10 +158,12 @@ public class ClassSanityTesterTest extends TestCase {
     fail();
   }
 
-  public static class BadNullsFactory {
+  public static final class BadNullsFactory {
     public static Object bad(@SuppressWarnings("unused") String a) {
       return new BadNulls();
     }
+
+    private BadNullsFactory() {}
   }
 
   @AndroidIncompatible // TODO(cpovirk): ClassNotFoundException... ClassSanityTesterTest$AnInterface
@@ -168,7 +171,7 @@ public class ClassSanityTesterTest extends TestCase {
     tester.forAllPublicStaticMethods(GoodSerializableFactory.class).testSerializable();
   }
 
-  public static class GoodSerializableFactory {
+  public static final class GoodSerializableFactory {
     public static Object good(Runnable r) {
       return r;
     }
@@ -176,6 +179,8 @@ public class ClassSanityTesterTest extends TestCase {
     public static Object good(AnInterface i) {
       return i;
     }
+
+    private GoodSerializableFactory() {}
   }
 
   public void testSerializableOnReturnValues_bad() throws Exception {
@@ -187,13 +192,14 @@ public class ClassSanityTesterTest extends TestCase {
     fail();
   }
 
-  public static class BadSerializableFactory {
+  public static final class BadSerializableFactory {
     public static Object bad() {
       return new Serializable() {
-        @SuppressWarnings("unused")
-        private final Object notSerializable = new Object();
+        @Keep private final Object notSerializable = new Object();
       };
     }
+
+    private BadSerializableFactory() {}
   }
 
   public void testEqualsAndSerializableOnReturnValues_equalsIsGoodButNotSerializable()
@@ -222,10 +228,12 @@ public class ClassSanityTesterTest extends TestCase {
         .testEqualsAndSerializable();
   }
 
-  public static class GoodEqualsAndSerializableFactory {
+  public static final class GoodEqualsAndSerializableFactory {
     public static Object good(AnInterface s) {
       return Functions.constant(s);
     }
+
+    private GoodEqualsAndSerializableFactory() {}
   }
 
   public void testEqualsForReturnValues_factoryReturnsNullButNotAnnotated() throws Exception {
@@ -269,10 +277,12 @@ public class ClassSanityTesterTest extends TestCase {
     fail();
   }
 
-  public static class FactoryThatReturnsNullButNotAnnotated {
+  public static final class FactoryThatReturnsNullButNotAnnotated {
     public static Object bad() {
       return null;
     }
+
+    private FactoryThatReturnsNullButNotAnnotated() {}
   }
 
   public void testEqualsForReturnValues_factoryReturnsNullAndAnnotated() throws Exception {
@@ -294,10 +304,12 @@ public class ClassSanityTesterTest extends TestCase {
         .testEqualsAndSerializable();
   }
 
-  public static class FactoryThatReturnsNullAndAnnotated {
+  public static final class FactoryThatReturnsNullAndAnnotated {
     public static @Nullable Object bad() {
       return null;
     }
+
+    private FactoryThatReturnsNullAndAnnotated() {}
   }
 
   public void testGoodEquals() throws Exception {
@@ -588,7 +600,7 @@ public class ClassSanityTesterTest extends TestCase {
 
   /** String doesn't check nulls as we expect. But the framework should ignore. */
   private static class JdkObjectFactory {
-    @SuppressWarnings("unused") // Called by reflection
+    @Keep
     public static Object create() {
       return new ArrayList<>();
     }
@@ -679,6 +691,7 @@ public class ClassSanityTesterTest extends TestCase {
   }
 
   private static class SetWrapper extends Wrapper {
+    @Keep
     public SetWrapper(Set<NotInstantiable> wrapped) {
       super(wrapped);
     }
@@ -725,7 +738,7 @@ public class ClassSanityTesterTest extends TestCase {
     }
 
     // keep trying
-    @SuppressWarnings("unused")
+    @Keep
     static GoodEquals create(int a, int b) {
       throw new RuntimeException();
     }
@@ -736,7 +749,7 @@ public class ClassSanityTesterTest extends TestCase {
     }
 
     // keep trying
-    @SuppressWarnings("unused")
+    @Keep
     public static @Nullable GoodEquals createMayReturnNull(int a, int b) {
       return null;
     }
@@ -1147,15 +1160,15 @@ public class ClassSanityTesterTest extends TestCase {
       checkNotNull(x);
     }
 
-    @SuppressWarnings("unused") // reflected
+    @Keep
     void primitiveOnly(int i) {}
 
-    @SuppressWarnings("unused") // reflected
+    @Keep
     void nullableOnly(@Nullable String s) {}
 
     public void noParameter() {}
 
-    @SuppressWarnings("unused") // reflected
+    @Keep
     void primitiveAndNullable(@Nullable String s, int i) {}
   }
 
@@ -1319,22 +1332,22 @@ public class ClassSanityTesterTest extends TestCase {
   private enum EnumFailsToCheckNull {
     A;
 
-    @SuppressWarnings("unused")
+    @Keep
     public void failToCheckNull(String s) {}
   }
 
   private interface AnInterface {}
 
   private abstract static class AnAbstractClass {
-    @SuppressWarnings("unused")
+    @Keep
     public AnAbstractClass(String s) {}
 
-    @SuppressWarnings("unused")
+    @Keep
     public void failsToCheckNull(String s) {}
   }
 
   private static class NoPublicStaticMethods {
-    @SuppressWarnings("unused") // To test non-public factory isn't used.
+    @Keep // To test non-public factory isn't used.
     static String notPublic() {
       return "";
     }
