@@ -44,7 +44,7 @@ import org.jspecify.annotations.NullMarked;
  *
  * @author Kevin Bourrillion
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @NullMarked
 public class CharMatcherTest extends TestCase {
 
