@@ -17,12 +17,12 @@
 package com.google.common.base;
 
 import static com.google.common.base.CharMatcher.whitespace;
-import static com.google.common.collect.Lists.newArrayList;
 import static org.junit.Assert.assertThrows;
 
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.annotations.GwtIncompatible;
 import com.google.common.annotations.J2ktIncompatible;
+import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableSet;
 import com.google.common.testing.ClassSanityTester;
 import com.google.common.testing.EqualsTester;
@@ -32,7 +32,6 @@ import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
-import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
 import java.util.regex.Pattern;
@@ -47,7 +46,7 @@ import org.jspecify.annotations.Nullable;
  * @author Kevin Bourrillion
  */
 @NullMarked
-@GwtCompatible(emulated = true)
+@GwtCompatible
 public class PredicatesTest extends TestCase {
   private static final Predicate<@Nullable Integer> TRUE = Predicates.alwaysTrue();
   private static final Predicate<@Nullable Integer> FALSE = Predicates.alwaysFalse();
@@ -311,7 +310,7 @@ public class PredicatesTest extends TestCase {
   }
 
   public void testAnd_listDefensivelyCopied() {
-    List<Predicate<Object>> list = newArrayList();
+    List<Predicate<Object>> list = new ArrayList<>();
     Predicate<Object> predicate = Predicates.and(list);
     assertTrue(predicate.apply(1));
     list.add(Predicates.alwaysFalse());
@@ -319,7 +318,7 @@ public class PredicatesTest extends TestCase {
   }
 
   public void testAnd_iterableDefensivelyCopied() {
-    final List<Predicate<Object>> list = newArrayList();
+    List<Predicate<Object>> list = new ArrayList<>();
     Iterable<Predicate<Object>> iterable =
         new Iterable<Predicate<Object>>() {
           @Override
@@ -425,14 +424,9 @@ public class PredicatesTest extends TestCase {
   }
 
   public void testOr_applyIterable() {
-    Predicate<@Nullable Integer> vacuouslyFalse =
-        Predicates.or(Collections.<Predicate<@Nullable Integer>>emptyList());
-    Predicate<@Nullable Integer> troo = Predicates.or(Collections.singletonList(TRUE));
-    /*
-     * newLinkedList() takes varargs. TRUE and FALSE are both instances of
-     * Predicate<Integer>, so the call is safe.
-     */
-    Predicate<@Nullable Integer> trueAndFalse = Predicates.or(Arrays.asList(TRUE, FALSE));
+    Predicate<@Nullable Integer> vacuouslyFalse = Predicates.or(ImmutableList.of());
+    Predicate<@Nullable Integer> troo = Predicates.or(ImmutableList.of(TRUE));
+    Predicate<@Nullable Integer> trueAndFalse = Predicates.or(ImmutableList.of(TRUE, FALSE));
 
     assertEvalsToFalse(vacuouslyFalse);
     assertEvalsToTrue(troo);
@@ -468,7 +462,7 @@ public class PredicatesTest extends TestCase {
   }
 
   public void testOr_listDefensivelyCopied() {
-    List<Predicate<Object>> list = newArrayList();
+    List<Predicate<Object>> list = new ArrayList<>();
     Predicate<Object> predicate = Predicates.or(list);
     assertFalse(predicate.apply(1));
     list.add(Predicates.alwaysTrue());
@@ -476,7 +470,7 @@ public class PredicatesTest extends TestCase {
   }
 
   public void testOr_iterableDefensivelyCopied() {
-    final List<Predicate<Object>> list = newArrayList();
+    List<Predicate<Object>> list = new ArrayList<>();
     Iterable<Predicate<Object>> iterable =
         new Iterable<Predicate<Object>>() {
           @Override
