@@ -16,11 +16,12 @@
 
 package com.google.common.base;
 
-
 import com.google.common.annotations.GwtCompatible;
+import org.jspecify.annotations.NullUnmarked;
 
 /** Exception classes for use in tests. */
 @GwtCompatible
+@NullUnmarked
 final class TestExceptions {
   static class SomeError extends Error {}
 
