@@ -24,6 +24,7 @@ import static com.google.common.cache.TestingRemovalListeners.nullRemovalListene
 import static com.google.common.cache.TestingRemovalListeners.queuingRemovalListener;
 import static com.google.common.cache.TestingWeighers.constantWeigher;
 import static com.google.common.truth.Truth.assertThat;
+import static java.util.concurrent.Executors.newFixedThreadPool;
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
 import static java.util.concurrent.TimeUnit.NANOSECONDS;
 import static java.util.concurrent.TimeUnit.SECONDS;
@@ -33,17 +34,16 @@ import com.google.common.annotations.GwtIncompatible;
 import com.google.common.base.Ticker;
 import com.google.common.cache.TestingRemovalListeners.CountingRemovalListener;
 import com.google.common.cache.TestingRemovalListeners.QueuingRemovalListener;
-import com.google.common.collect.Maps;
 import com.google.common.collect.Sets;
 import com.google.common.testing.NullPointerTester;
 import com.google.errorprone.annotations.CanIgnoreReturnValue;
 import java.time.Duration;
+import java.util.HashMap;
 import java.util.Map;
 import java.util.Random;
 import java.util.Set;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
@@ -51,7 +51,7 @@ import junit.framework.TestCase;
 import org.jspecify.annotations.NullUnmarked;
 
 /** Unit tests for CacheBuilder. */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 // We are intentionally testing the TimeUnit overloads, too.
 @SuppressWarnings("LongTimeUnit_ExpireAfterWrite_Seconds")
 @NullUnmarked
@@ -348,8 +348,8 @@ public class CacheBuilderTest extends TestCase {
     // If a clear() happens while a computation is pending, we should not get a removal
     // notification.
 
-    final AtomicBoolean shouldWait = new AtomicBoolean(false);
-    final CountDownLatch computingLatch = new CountDownLatch(1);
+    AtomicBoolean shouldWait = new AtomicBoolean(false);
+    CountDownLatch computingLatch = new CountDownLatch(1);
     CacheLoader<String, String> computingFunction =
         new CacheLoader<String, String>() {
           @Override
@@ -362,7 +362,7 @@ public class CacheBuilderTest extends TestCase {
         };
     QueuingRemovalListener<String, String> listener = queuingRemovalListener();
 
-    final LoadingCache<String, String> cache =
+    LoadingCache<String, String> cache =
         CacheBuilder.newBuilder()
             .concurrencyLevel(1)
             .removalListener(listener)
@@ -372,8 +372,8 @@ public class CacheBuilderTest extends TestCase {
     cache.getUnchecked("a");
     shouldWait.set(true);
 
-    final CountDownLatch computationStarted = new CountDownLatch(1);
-    final CountDownLatch computationComplete = new CountDownLatch(1);
+    CountDownLatch computationStarted = new CountDownLatch(1);
+    CountDownLatch computationComplete = new CountDownLatch(1);
     new Thread(
             new Runnable() {
               @Override
@@ -424,7 +424,7 @@ public class CacheBuilderTest extends TestCase {
     AtomicBoolean computationShouldWait = new AtomicBoolean();
     CountDownLatch computationLatch = new CountDownLatch(1);
     QueuingRemovalListener<String, String> listener = queuingRemovalListener();
-    final LoadingCache<String, String> cache =
+    LoadingCache<String, String> cache =
         CacheBuilder.newBuilder()
             .removalListener(listener)
             .concurrencyLevel(20)
@@ -443,11 +443,11 @@ public class CacheBuilderTest extends TestCase {
     }
     computationShouldWait.set(true);
 
-    final AtomicInteger computedCount = new AtomicInteger();
-    ExecutorService threadPool = Executors.newFixedThreadPool(nThreads);
-    final CountDownLatch tasksFinished = new CountDownLatch(nTasks);
+    AtomicInteger computedCount = new AtomicInteger();
+    ExecutorService threadPool = newFixedThreadPool(nThreads);
+    CountDownLatch tasksFinished = new CountDownLatch(nTasks);
     for (int i = 0; i < nTasks; i++) {
-      final String s = "a" + i;
+      String s = "a" + i;
       @SuppressWarnings("unused") // https://errorprone.info/bugpattern/FutureReturnValueIgnored
       Future<?> possiblyIgnoredError =
           threadPool.submit(
@@ -473,7 +473,7 @@ public class CacheBuilderTest extends TestCase {
     // Check all of the removal notifications we received: they should have had correctly-associated
     // keys and values. (An earlier bug saw removal notifications for in-progress computations,
     // which had real keys with null values.)
-    Map<String, String> removalNotifications = Maps.newHashMap();
+    Map<String, String> removalNotifications = new HashMap<>();
     for (RemovalNotification<String, String> notification : listener) {
       removalNotifications.put(notification.getKey(), notification.getValue());
       assertEquals(
@@ -505,14 +505,14 @@ public class CacheBuilderTest extends TestCase {
   public void testRemovalNotification_get_basher() throws InterruptedException {
     int nTasks = 1000;
     int nThreads = 100;
-    final int getsPerTask = 1000;
-    final int nUniqueKeys = 10000;
-    final Random random = new Random(); // Randoms.insecureRandom();
+    int getsPerTask = 1000;
+    int nUniqueKeys = 10000;
+    Random random = new Random(); // Randoms.insecureRandom();
 
     QueuingRemovalListener<String, String> removalListener = queuingRemovalListener();
-    final AtomicInteger computeCount = new AtomicInteger();
-    final AtomicInteger exceptionCount = new AtomicInteger();
-    final AtomicInteger computeNullCount = new AtomicInteger();
+    AtomicInteger computeCount = new AtomicInteger();
+    AtomicInteger exceptionCount = new AtomicInteger();
+    AtomicInteger computeNullCount = new AtomicInteger();
     @SuppressWarnings("CacheLoaderNull") // test of handling of erroneous implementation
     CacheLoader<String, String> countingIdentityLoader =
         new CacheLoader<String, String>() {
@@ -535,7 +535,7 @@ public class CacheBuilderTest extends TestCase {
             }
           }
         };
-    final LoadingCache<String, String> cache =
+    LoadingCache<String, String> cache =
         CacheBuilder.newBuilder()
             .recordStats()
             .concurrencyLevel(2)
@@ -544,7 +544,7 @@ public class CacheBuilderTest extends TestCase {
             .maximumSize(5000)
             .build(countingIdentityLoader);
 
-    ExecutorService threadPool = Executors.newFixedThreadPool(nThreads);
+    ExecutorService threadPool = newFixedThreadPool(nThreads);
     for (int i = 0; i < nTasks; i++) {
       @SuppressWarnings("unused") // https://errorprone.info/bugpattern/FutureReturnValueIgnored
       Future<?> possiblyIgnoredError =
