@@ -32,6 +32,7 @@ import java.util.Set;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.atomic.AtomicInteger;
 import junit.framework.TestCase;
+import org.jspecify.annotations.NullUnmarked;
 
 /**
  * Tests relating to cache expiration: make sure entries expire at the right times, make sure
@@ -40,6 +41,7 @@ import junit.framework.TestCase;
  * @author mike nonemacher
  */
 @SuppressWarnings("deprecation") // tests of deprecated method
+@NullUnmarked
 public class CacheExpirationTest extends TestCase {
 
   private static final long EXPIRING_TIME = 1000;
@@ -176,9 +178,9 @@ public class CacheExpirationTest extends TestCase {
 
   public void testRemovalListener_expireAfterWrite() {
     FakeTicker ticker = new FakeTicker();
-    final AtomicInteger evictionCount = new AtomicInteger();
-    final AtomicInteger applyCount = new AtomicInteger();
-    final AtomicInteger totalSum = new AtomicInteger();
+    AtomicInteger evictionCount = new AtomicInteger();
+    AtomicInteger applyCount = new AtomicInteger();
+    AtomicInteger totalSum = new AtomicInteger();
 
     RemovalListener<Integer, AtomicInteger> removalListener =
         new RemovalListener<Integer, AtomicInteger>() {
@@ -486,21 +488,21 @@ public class CacheExpirationTest extends TestCase {
     String keyPrefix = KEY_PREFIX;
     int valuePrefix = VALUE_PREFIX;
 
-    public WatchedCreatorLoader() {}
+    WatchedCreatorLoader() {}
 
-    public void reset() {
+    void reset() {
       wasCalled = false;
     }
 
-    public boolean wasCalled() {
+    boolean wasCalled() {
       return wasCalled;
     }
 
-    public void setKeyPrefix(String keyPrefix) {
+    void setKeyPrefix(String keyPrefix) {
       this.keyPrefix = keyPrefix;
     }
 
-    public void setValuePrefix(int valuePrefix) {
+    void setValuePrefix(int valuePrefix) {
       this.valuePrefix = valuePrefix;
     }
 
