@@ -125,6 +125,23 @@ public class LocalCacheMapComputeTest extends TestCase {
     CacheTesting.checkEmpty(cache);
   }
 
+  public void testComputeIfPresent_error() {
+    Cache<String, String> cache = CacheBuilder.newBuilder().build();
+    cache.put(key, "1");
+    assertThrows(
+        Error.class,
+        () ->
+            cache
+                .asMap()
+                .computeIfPresent(
+                    key,
+                    (k, v) -> {
+                      throw new Error();
+                    }));
+    assertThat(cache.getIfPresent(key)).isEqualTo("1");
+    assertThat(cache.asMap().computeIfPresent(key, (k, v) -> "2")).isEqualTo("2");
+  }
+
   public void testUpdates() {
     cache.put(key, "1");
     // simultaneous update for same key, some null, some non-null
