@@ -16,12 +16,12 @@
 
 package com.google.common.collect;
 
-import static com.google.common.collect.Sets.newHashSet;
 
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.base.Joiner;
 import com.google.common.collect.testing.MapInterfaceTest;
 import com.google.common.collect.testing.MinimalSet;
+import java.util.HashSet;
 import java.util.Map;
 import java.util.Map.Entry;
 import org.jspecify.annotations.NullUnmarked;
@@ -53,6 +53,6 @@ abstract class AbstractImmutableMapMapInterfaceTest<K, V> extends MapInterfaceTe
     assertEquals("[" + JOINER.join(map.values()) + "]", map.values().toString());
 
     assertEquals(MinimalSet.from(map.entrySet()), map.entrySet());
-    assertEquals(newHashSet(map.keySet()), map.keySet());
+    assertEquals(new HashSet<>(map.keySet()), map.keySet());
   }
 }
