@@ -19,7 +19,6 @@ package com.google.common.collect;
 import static com.google.common.base.Strings.isNullOrEmpty;
 import static com.google.common.collect.Iterables.concat;
 import static com.google.common.collect.Lists.newArrayList;
-import static com.google.common.collect.Lists.newLinkedList;
 import static com.google.common.truth.Truth.assertThat;
 import static java.util.Collections.nCopies;
 
@@ -32,9 +31,11 @@ import com.google.common.collect.testing.TestStringCollectionGenerator;
 import com.google.common.collect.testing.features.CollectionFeature;
 import com.google.common.collect.testing.features.CollectionSize;
 import com.google.common.testing.NullPointerTester;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Iterator;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.NoSuchElementException;
 import java.util.Objects;
@@ -50,7 +51,7 @@ import org.jspecify.annotations.Nullable;
  * @author Chris Povirk
  * @author Jared Levy
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @NullMarked
 public class Collections2Test extends TestCase {
   @J2ktIncompatible
@@ -81,7 +82,7 @@ public class Collections2Test extends TestCase {
             new TestStringCollectionGenerator() {
               @Override
               public Collection<String> create(String[] elements) {
-                List<String> unfiltered = newArrayList();
+                List<String> unfiltered = new ArrayList<>();
                 unfiltered.add("yyy");
                 Collections.addAll(unfiltered, elements);
                 unfiltered.add("zzz");
@@ -106,7 +107,7 @@ public class Collections2Test extends TestCase {
             new TestStringCollectionGenerator() {
               @Override
               public Collection<String> create(String[] elements) {
-                List<String> unfiltered = newArrayList();
+                List<String> unfiltered = new ArrayList<>();
                 Collections.addAll(unfiltered, elements);
                 return Collections2.filter(unfiltered, NOT_YYY_ZZZ);
               }
@@ -129,7 +130,7 @@ public class Collections2Test extends TestCase {
             new TestStringCollectionGenerator() {
               @Override
               public Collection<String> create(String[] elements) {
-                List<String> unfiltered = newLinkedList();
+                List<String> unfiltered = new LinkedList<>();
                 unfiltered.add("yyy");
                 Collections.addAll(unfiltered, elements);
                 unfiltered.add("zzz");
@@ -154,7 +155,7 @@ public class Collections2Test extends TestCase {
             new TestStringCollectionGenerator() {
               @Override
               public Collection<String> create(String[] elements) {
-                List<String> unfiltered = newArrayList();
+                List<String> unfiltered = new ArrayList<>();
                 unfiltered.add("yyy");
                 unfiltered.addAll(ImmutableList.copyOf(elements));
                 unfiltered.add("zzz");
@@ -179,7 +180,7 @@ public class Collections2Test extends TestCase {
             new TestStringCollectionGenerator() {
               @Override
               public Collection<String> create(String[] elements) {
-                List<String> unfiltered = newArrayList();
+                List<String> unfiltered = new ArrayList<>();
                 unfiltered.add("yyy");
                 unfiltered.addAll(ImmutableList.copyOf(elements));
                 unfiltered.add("zzz");
@@ -205,7 +206,7 @@ public class Collections2Test extends TestCase {
             new TestStringCollectionGenerator() {
               @Override
               public Collection<@Nullable String> create(@Nullable String[] elements) {
-                List<@Nullable String> list = newArrayList();
+                List<@Nullable String> list = new ArrayList<>();
                 for (String element : elements) {
                   list.add((element == null) ? null : "q" + element);
                 }
@@ -230,7 +231,7 @@ public class Collections2Test extends TestCase {
   }
 
   public void testOrderedPermutationSetEmpty() {
-    List<Integer> list = newArrayList();
+    List<Integer> list = new ArrayList<>();
     Collection<List<Integer>> permutationSet = Collections2.orderedPermutations(list);
 
     assertEquals(1, permutationSet.size());
@@ -238,7 +239,7 @@ public class Collections2Test extends TestCase {
 
     Iterator<List<Integer>> permutations = permutationSet.iterator();
 
-    assertNextPermutation(Lists.<Integer>newArrayList(), permutations);
+    assertNextPermutation(new ArrayList<>(), permutations);
     assertNoMorePermutations(permutations);
   }
 
@@ -491,7 +492,7 @@ public class Collections2Test extends TestCase {
   }
 
   public void testToStringImplWithNullEntries() throws Exception {
-    List<@Nullable String> list = Lists.newArrayList();
+    List<@Nullable String> list = new ArrayList<>();
     list.add("foo");
     list.add(null);
 
