@@ -20,8 +20,10 @@ import static java.lang.Math.log;
 
 import com.google.common.annotations.GwtIncompatible;
 import java.util.Map;
+import org.jspecify.annotations.NullUnmarked;
 
 @GwtIncompatible
+@NullUnmarked
 public class CompactHashMapFloodingTest extends AbstractHashFloodingTest<Map<Object, Object>> {
   public CompactHashMapFloodingTest() {
     super(
