@@ -60,7 +60,7 @@ import org.jspecify.annotations.Nullable;
  *
  * @author Jared Levy
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @NullMarked
 public class ImmutableBiMapTest extends TestCase {
 
@@ -538,7 +538,7 @@ public class ImmutableBiMapTest extends TestCase {
   }
 
   public void testFromHashMap() {
-    Map<String, Integer> hashMap = Maps.newLinkedHashMap();
+    Map<String, Integer> hashMap = new LinkedHashMap<>();
     hashMap.put("one", 1);
     hashMap.put("two", 2);
     ImmutableBiMap<String, Integer> bimap = ImmutableBiMap.copyOf(hashMap);
