@@ -63,7 +63,7 @@ import org.jspecify.annotations.Nullable;
  * @author George van den Driessche
  * @author Jared Levy
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @NullMarked
 public class ImmutableListTest extends TestCase {
 
@@ -547,7 +547,7 @@ public class ImmutableListTest extends TestCase {
     assertEquals(0x003300, (int) webSafeColors.get(6));
     ImmutableList<Integer> addedColor = webSafeColorsBuilder.add(0x00BFFF).build();
     assertEquals(
-        "Modifying the builder should not have changed any already" + " built sets",
+        "Modifying the builder should not have changed any already built sets",
         216,
         webSafeColors.size());
     assertEquals("the new array should be one bigger than webSafeColors", 217, addedColor.size());
