@@ -55,6 +55,7 @@ import java.io.ByteArrayOutputStream;
 import java.io.ObjectOutputStream;
 import java.io.Serializable;
 import java.util.AbstractMap;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.EnumMap;
@@ -79,7 +80,7 @@ import org.jspecify.annotations.Nullable;
  * @author Kevin Bourrillion
  * @author Jesse Wilson
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @SuppressWarnings("AlwaysThrows")
 @NullMarked
 public class ImmutableMapTest extends TestCase {
@@ -328,7 +329,7 @@ public class ImmutableMapTest extends TestCase {
 
   public void testBuilder_withMutableEntry() {
     ImmutableMap.Builder<String, Integer> builder = new Builder<>();
-    final StringHolder holder = new StringHolder();
+    StringHolder holder = new StringHolder();
     holder.string = "one";
     Entry<String, Integer> entry =
         new AbstractMapEntry<String, Integer>() {
@@ -872,9 +873,9 @@ public class ImmutableMapTest extends TestCase {
   }
 
   private static class IntHolder implements Serializable {
-    public int value;
+    private int value;
 
-    public IntHolder(int value) {
+    IntHolder(int value) {
       this.value = value;
     }
 
@@ -917,7 +918,7 @@ public class ImmutableMapTest extends TestCase {
     LenientSerializableTester.reserializeAndAssertLenient(map.keySet());
 
     Collection<Integer> reserializedValues = reserialize(map.values());
-    assertEquals(Lists.newArrayList(map.values()), Lists.newArrayList(reserializedValues));
+    assertEquals(new ArrayList<>(map.values()), new ArrayList<>(reserializedValues));
     assertTrue(reserializedValues instanceof ImmutableCollection);
   }
 
