@@ -57,7 +57,7 @@ import org.jspecify.annotations.Nullable;
  *
  * @author Mike Ward
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @NullMarked
 public class ImmutableSetMultimapTest extends TestCase {
   @J2ktIncompatible
@@ -214,7 +214,7 @@ public class ImmutableSetMultimapTest extends TestCase {
 
   public void testBuilder_withMutableEntry() {
     ImmutableSetMultimap.Builder<String, Integer> builder = new Builder<>();
-    final StringHolder holder = new StringHolder();
+    StringHolder holder = new StringHolder();
     holder.string = "one";
     Entry<String, Integer> entry =
         new AbstractMapEntry<String, Integer>() {
