@@ -20,15 +20,16 @@ import static com.google.common.collect.ReflectionFreeAssertThrows.assertThrows;
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.annotations.GwtIncompatible;
 import com.google.common.annotations.J2ktIncompatible;
-import com.google.common.base.Objects;
 import com.google.common.collect.testing.features.CollectionFeature;
 import com.google.common.collect.testing.features.CollectionSize;
 import com.google.common.collect.testing.google.MultisetTestSuiteBuilder;
 import com.google.common.collect.testing.google.TestStringMultisetGenerator;
 import java.io.Serializable;
 import java.util.Collections;
+import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
+import java.util.Objects;
 import java.util.concurrent.atomic.AtomicInteger;
 import junit.framework.Test;
 import junit.framework.TestCase;
@@ -43,7 +44,7 @@ import org.jspecify.annotations.Nullable;
  * @author Louis Wasserman
  */
 @SuppressWarnings("serial") // No serialization is used in this test
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @NullMarked
 public class SimpleAbstractMultisetTest extends TestCase {
   @J2ktIncompatible
@@ -73,7 +74,7 @@ public class SimpleAbstractMultisetTest extends TestCase {
 
   @SuppressWarnings("ModifiedButNotUsed")
   public void testFastAddAllMultiset() {
-    final AtomicInteger addCalls = new AtomicInteger();
+    AtomicInteger addCalls = new AtomicInteger();
     Multiset<String> multiset =
         new NoRemoveMultiset<String>() {
           @Override
@@ -97,7 +98,7 @@ public class SimpleAbstractMultisetTest extends TestCase {
 
   private static class NoRemoveMultiset<E extends @Nullable Object> extends AbstractMultiset<E>
       implements Serializable {
-    final Map<E, Integer> backingMap = Maps.newHashMap();
+    final Map<E, Integer> backingMap = new HashMap<>();
 
     @Override
     public int size() {
@@ -112,7 +113,7 @@ public class SimpleAbstractMultisetTest extends TestCase {
     @Override
     public int count(@Nullable Object element) {
       for (Entry<E> entry : entrySet()) {
-        if (Objects.equal(entry.getElement(), element)) {
+        if (Objects.equals(entry.getElement(), element)) {
           return entry.getCount();
         }
       }
@@ -138,7 +139,7 @@ public class SimpleAbstractMultisetTest extends TestCase {
 
     @Override
     Iterator<Entry<E>> entryIterator() {
-      final Iterator<Map.Entry<E, Integer>> backingEntries = backingMap.entrySet().iterator();
+      Iterator<Map.Entry<E, Integer>> backingEntries = backingMap.entrySet().iterator();
       return new UnmodifiableIterator<Multiset.Entry<E>>() {
         @Override
         public boolean hasNext() {
@@ -147,7 +148,7 @@ public class SimpleAbstractMultisetTest extends TestCase {
 
         @Override
         public Multiset.Entry<E> next() {
-          final Map.Entry<E, Integer> mapEntry = backingEntries.next();
+          Map.Entry<E, Integer> mapEntry = backingEntries.next();
           return new Multisets.AbstractEntry<E>() {
             @Override
             public E getElement() {
