@@ -18,9 +18,10 @@ package com.google.common.collect;
 
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.collect.TableCollectionTest.RowMapTests;
+import org.jspecify.annotations.NullMarked;
 
 @GwtCompatible
-@ElementTypesAreNonnullByDefault
+@NullMarked
 public class TreeBasedTableRowMapTest extends RowMapTests {
   public TreeBasedTableRowMapTest() {
     super(false, true, true, true);
