@@ -31,7 +31,7 @@ import org.jspecify.annotations.NullMarked;
  *
  * @author Louis Wasserman
  */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 @NullMarked
 public class TreeTraverserTest extends TestCase {
   private static class Node {
@@ -45,7 +45,7 @@ public class TreeTraverserTest extends TestCase {
   private static final class Tree extends Node {
     final List<Tree> children;
 
-    public Tree(char value, Tree... children) {
+    Tree(char value, Tree... children) {
       super(value);
       this.children = asList(children);
     }
