@@ -16,6 +16,8 @@
 
 package com.google.common.hash;
 
+import static com.google.common.hash.BloomFilter.toBloomFilter;
+import static com.google.common.hash.Funnels.unencodedCharsFunnel;
 import static com.google.common.truth.Truth.assertThat;
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static java.util.concurrent.TimeUnit.SECONDS;
@@ -37,6 +39,7 @@ import java.math.RoundingMode;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Random;
+import java.util.stream.Stream;
 import junit.framework.TestCase;
 import org.jspecify.annotations.NullUnmarked;
 import org.jspecify.annotations.Nullable;
@@ -408,7 +411,7 @@ public class BloomFilterTest extends TestCase {
 
     @Override
     public boolean equals(@Nullable Object object) {
-      return (object instanceof CustomFunnel);
+      return object instanceof CustomFunnel;
     }
 
     @Override
@@ -525,7 +528,7 @@ public class BloomFilterTest extends TestCase {
 
 
   public void testNoRaceConditions() throws Exception {
-    final BloomFilter<Integer> bloomFilter =
+    BloomFilter<Integer> bloomFilter =
         BloomFilter.create(Funnels.integerFunnel(), 15_000_000, 0.01);
 
     // This check has to be BEFORE the loop because the random insertions can
@@ -538,8 +541,8 @@ public class BloomFilterTest extends TestCase {
     bloomFilter.put(GOLDEN_PRESENT_KEY);
 
     int numThreads = 12;
-    final double safetyFalsePositiveRate = 0.1;
-    final Stopwatch stopwatch = Stopwatch.createStarted();
+    double safetyFalsePositiveRate = 0.1;
+    Stopwatch stopwatch = Stopwatch.createStarted();
 
     Runnable task =
         new Runnable() {
@@ -575,7 +578,7 @@ public class BloomFilterTest extends TestCase {
 
   private static List<Throwable> runThreadsAndReturnExceptions(int numThreads, Runnable task) {
     List<Thread> threads = new ArrayList<>(numThreads);
-    final List<Throwable> exceptions = new ArrayList<>(numThreads);
+    List<Throwable> exceptions = new ArrayList<>(numThreads);
     for (int i = 0; i < numThreads; i++) {
       Thread thread = new Thread(task);
       thread.setUncaughtExceptionHandler(
@@ -603,4 +606,13 @@ public class BloomFilterTest extends TestCase {
     } while (key == GOLDEN_PRESENT_KEY);
     return key;
   }
+
+  public void testToBloomFilter() {
+    BloomFilter<String> bf1 = BloomFilter.create(unencodedCharsFunnel(), 2);
+    bf1.put("1");
+    bf1.put("2");
+
+    assertEquals(bf1, Stream.of("1", "2").collect(toBloomFilter(unencodedCharsFunnel(), 2)));
+    assertEquals(bf1, Stream.of("2", "1").collect(toBloomFilter(unencodedCharsFunnel(), 2)));
+  }
 }
