@@ -28,6 +28,7 @@ import java.io.IOException;
 import java.io.Reader;
 import java.io.StringReader;
 import java.nio.CharBuffer;
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 import org.jspecify.annotations.NullUnmarked;
@@ -85,7 +86,7 @@ public class LineBufferTest extends IoTestCase {
   }
 
   private static List<String> bufferHelper(String input, int chunk) throws IOException {
-    final List<String> lines = Lists.newArrayList();
+    List<String> lines = new ArrayList<>();
     LineBuffer lineBuf =
         new LineBuffer() {
           @Override
@@ -106,7 +107,7 @@ public class LineBufferTest extends IoTestCase {
 
   private static List<String> readUsingJava(String input, int chunk) throws IOException {
     BufferedReader r = new BufferedReader(getChunkedReader(input, chunk));
-    List<String> lines = Lists.newArrayList();
+    List<String> lines = new ArrayList<>();
     String line;
     while ((line = r.readLine()) != null) {
       lines.add(line);
@@ -120,7 +121,7 @@ public class LineBufferTest extends IoTestCase {
     Readable readable =
         asReader ? getChunkedReader(input, chunk) : getChunkedReadable(input, chunk);
     LineReader r = new LineReader(readable);
-    List<String> lines = Lists.newArrayList();
+    List<String> lines = new ArrayList<>();
     String line;
     while ((line = r.readLine()) != null) {
       lines.add(line);
@@ -130,7 +131,7 @@ public class LineBufferTest extends IoTestCase {
 
   // Returns a Readable that is *not* a Reader.
   private static Readable getChunkedReadable(String input, int chunk) {
-    final Reader reader = getChunkedReader(input, chunk);
+    Reader reader = getChunkedReader(input, chunk);
     return new Readable() {
       @Override
       public int read(CharBuffer cbuf) throws IOException {
@@ -139,7 +140,7 @@ public class LineBufferTest extends IoTestCase {
     };
   }
 
-  private static Reader getChunkedReader(String input, final int chunk) {
+  private static Reader getChunkedReader(String input, int chunk) {
     return new FilterReader(new StringReader(input)) {
       @Override
       public int read(char[] cbuf, int off, int len) throws IOException {
