@@ -136,7 +136,7 @@ public class SourceSinkFactories {
     return new PathCharSinkFactory(initialString);
   }
 
-  public static ByteSourceFactory asByteSourceFactory(final CharSourceFactory factory) {
+  public static ByteSourceFactory asByteSourceFactory(CharSourceFactory factory) {
     checkNotNull(factory);
     return new ByteSourceFactory() {
       @Override
@@ -156,7 +156,7 @@ public class SourceSinkFactories {
     };
   }
 
-  public static CharSourceFactory asCharSourceFactory(final ByteSourceFactory factory) {
+  public static CharSourceFactory asCharSourceFactory(ByteSourceFactory factory) {
     checkNotNull(factory);
     return new CharSourceFactory() {
       @Override
@@ -176,7 +176,7 @@ public class SourceSinkFactories {
     };
   }
 
-  public static CharSinkFactory asCharSinkFactory(final ByteSinkFactory factory) {
+  public static CharSinkFactory asCharSinkFactory(ByteSinkFactory factory) {
     checkNotNull(factory);
     return new CharSinkFactory() {
       @Override
@@ -207,7 +207,7 @@ public class SourceSinkFactories {
   }
 
   public static ByteSourceFactory asSlicedByteSourceFactory(
-      final ByteSourceFactory factory, final long off, final long len) {
+      ByteSourceFactory factory, long off, long len) {
     checkNotNull(factory);
     return new ByteSourceFactory() {
       @Override
@@ -300,16 +300,18 @@ public class SourceSinkFactories {
 
     private final ThreadLocal<File> fileThreadLocal = new ThreadLocal<>();
 
-    protected File createFile() throws IOException {
+    File createFile() throws IOException {
       File file = File.createTempFile("SinkSourceFile", "txt");
       fileThreadLocal.set(file);
       return file;
     }
 
-    protected File getFile() {
+    File getFile() {
       return fileThreadLocal.get();
     }
 
+    // acts as an override in subclasses that implement SourceSinkFactory
+    @SuppressWarnings("EffectivelyPrivate")
     public final void tearDown() throws IOException {
       if (!fileThreadLocal.get().delete()) {
         logger.warning("Unable to delete file: " + fileThreadLocal.get());
@@ -480,16 +482,18 @@ public class SourceSinkFactories {
 
     private final ThreadLocal<Path> fileThreadLocal = new ThreadLocal<>();
 
-    protected Path createFile() throws IOException {
+    Path createFile() throws IOException {
       Path file = java.nio.file.Files.createTempFile("SinkSourceFile", "txt");
       fileThreadLocal.set(file);
       return file;
     }
 
-    protected Path getPath() {
+    Path getPath() {
       return fileThreadLocal.get();
     }
 
+    // acts as an override in subclasses that implement SourceSinkFactory
+    @SuppressWarnings("EffectivelyPrivate")
     public final void tearDown() throws IOException {
       try {
         java.nio.file.Files.delete(fileThreadLocal.get());
