@@ -46,7 +46,7 @@ import org.jspecify.annotations.Nullable;
  * @author Kevin Bourrillion
  */
 @NullMarked
-@GwtCompatible(emulated = true)
+@GwtCompatible
 public class FloatsTest extends TestCase {
   private static final float[] EMPTY = {};
   private static final float[] ARRAY1 = {1.0f};
@@ -77,16 +77,18 @@ public class FloatsTest extends TestCase {
 
   private static final float[] VALUES = Floats.concat(NUMBERS, new float[] {NaN});
 
+  // We need to test that our method behaves like the JDK method.
+  @SuppressWarnings("InlineMeInliner")
   public void testHashCode() {
     for (float value : VALUES) {
       assertThat(Floats.hashCode(value)).isEqualTo(Float.hashCode(value));
     }
   }
 
+  @SuppressWarnings("InlineMeInliner") // We need to test our method.
   public void testIsFinite() {
     for (float value : NUMBERS) {
-      assertThat(Floats.isFinite(value))
-          .isEqualTo(!(Float.isInfinite(value) || Float.isNaN(value)));
+      assertThat(Floats.isFinite(value)).isEqualTo(Float.isFinite(value));
     }
   }
 
@@ -572,6 +574,8 @@ public class FloatsTest extends TestCase {
     assertThat(Floats.toArray(list.subList(2, 2))).isEmpty();
   }
 
+  // `primitives` can't depend on `collect`, so this is what the prod code has to return.
+  @SuppressWarnings("EmptyList")
   public void testAsListEmpty() {
     assertThat(Floats.asList(EMPTY)).isSameInstanceAs(Collections.emptyList());
   }
