@@ -32,7 +32,7 @@ import java.util.concurrent.TimeoutException;
 import org.jspecify.annotations.Nullable;
 
 /** Methods factored out so that they can be emulated differently in GWT. */
-@GwtCompatible(emulated = true)
+@GwtCompatible
 final class TestPlatform {
   static void verifyGetOnPendingFuture(Future<?> future) {
     checkNotNull(future);
