@@ -8,18 +8,18 @@ val expectedReducedRuntimeClasspathAndroidVersion =
   setOf(
     "guava-${guavaVersionJre.replace("jre", "android")}.jar",
     "failureaccess-1.0.3.jar",
-    "j2objc-annotations-3.0.0.jar",
+    "j2objc-annotations-3.1.jar",
     "jspecify-1.0.0.jar",
-    "error_prone_annotations-2.36.0.jar",
+    "error_prone_annotations-2.41.0.jar",
     "listenablefuture-9999.0-empty-to-avoid-conflict-with-guava.jar"
   )
 val expectedReducedRuntimeClasspathJreVersion =
   setOf(
     "guava-$guavaVersionJre.jar",
     "failureaccess-1.0.3.jar",
-    "j2objc-annotations-3.0.0.jar",
+    "j2objc-annotations-3.1.jar",
     "jspecify-1.0.0.jar",
-    "error_prone_annotations-2.36.0.jar",
+    "error_prone_annotations-2.41.0.jar",
     "listenablefuture-9999.0-empty-to-avoid-conflict-with-guava.jar"
   )
 val expectedCompileClasspathAndroidVersion = expectedReducedRuntimeClasspathAndroidVersion
